@@ -37,7 +37,7 @@ enum  {
 	VALA_CCODE_ASSIGNMENT_DUMMY_PROPERTY,
 	VALA_CCODE_ASSIGNMENT_LEFT,
 	VALA_CCODE_ASSIGNMENT_OPERATOR,
-	VALA_CCODE_ASSIGNMENT_RIGHT,
+	VALA_CCODE_ASSIGNMENT_RIGHT
 };
 static void vala_ccode_assignment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_assignment_parent_class = NULL;
@@ -46,21 +46,25 @@ static void vala_ccode_assignment_dispose (GObject * obj);
 
 ValaCCodeAssignment* vala_ccode_assignment_new (ValaCCodeExpression* l, ValaCCodeExpression* r, ValaCCodeAssignmentOperator op)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeAssignment * self;
 	g_return_val_if_fail (l == NULL || VALA_IS_CCODE_EXPRESSION (l), NULL);
 	g_return_val_if_fail (r == NULL || VALA_IS_CCODE_EXPRESSION (r), NULL);
-	GParameter * __params = g_new0 (GParameter, 3);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
 	(__params_it->name = "left", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, l), __params_it++);
 	(__params_it->name = "operator", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, op), __params_it++);
 	(__params_it->name = "right", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, r), __params_it++);
-	ValaCCodeAssignment * self = g_object_newv (VALA_TYPE_CCODE_ASSIGNMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_ASSIGNMENT, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_ccode_assignment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeAssignment * self = VALA_CCODE_ASSIGNMENT (base);
+	ValaCCodeAssignment * self;
+	self = VALA_CCODE_ASSIGNMENT (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (vala_ccode_assignment_get_left (self) != NULL) {
 		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_assignment_get_left (self)), writer);
@@ -121,9 +125,11 @@ ValaCCodeExpression* vala_ccode_assignment_get_left (ValaCCodeAssignment* self)
 
 void vala_ccode_assignment_set_left (ValaCCodeAssignment* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp2;
+	ValaCCodeExpression* __temp1;
 	g_return_if_fail (VALA_IS_CCODE_ASSIGNMENT (self));
-	ValaCCodeExpression* __temp2 = NULL;
-	ValaCCodeExpression* __temp1 = NULL;
+	__temp2 = NULL;
+	__temp1 = NULL;
 	self->priv->_left = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL))), __temp2);
 }
 
@@ -151,16 +157,19 @@ ValaCCodeExpression* vala_ccode_assignment_get_right (ValaCCodeAssignment* self)
 
 void vala_ccode_assignment_set_right (ValaCCodeAssignment* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp6;
+	ValaCCodeExpression* __temp5;
 	g_return_if_fail (VALA_IS_CCODE_ASSIGNMENT (self));
-	ValaCCodeExpression* __temp6 = NULL;
-	ValaCCodeExpression* __temp5 = NULL;
+	__temp6 = NULL;
+	__temp5 = NULL;
 	self->priv->_right = (__temp6 = (__temp5 = value, (__temp5 == NULL ? NULL : g_object_ref (__temp5))), (self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL))), __temp6);
 }
 
 
 static void vala_ccode_assignment_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeAssignment * self = VALA_CCODE_ASSIGNMENT (object);
+	ValaCCodeAssignment * self;
+	self = VALA_CCODE_ASSIGNMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_ASSIGNMENT_LEFT:
 		g_value_set_object (value, vala_ccode_assignment_get_left (self));
@@ -177,7 +186,8 @@ static void vala_ccode_assignment_get_property (GObject * object, guint property
 
 static void vala_ccode_assignment_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeAssignment * self = VALA_CCODE_ASSIGNMENT (object);
+	ValaCCodeAssignment * self;
+	self = VALA_CCODE_ASSIGNMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_ASSIGNMENT_LEFT:
 		vala_ccode_assignment_set_left (self, g_value_get_object (value));
@@ -214,11 +224,12 @@ static void vala_ccode_assignment_init (ValaCCodeAssignment * self)
 
 static void vala_ccode_assignment_dispose (GObject * obj)
 {
-	ValaCCodeAssignment * self = VALA_CCODE_ASSIGNMENT (obj);
-	(self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL)));
-	(self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL)));
+	ValaCCodeAssignment * self;
 	ValaCCodeAssignmentClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_ASSIGNMENT (obj);
+	(self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL)));
+	(self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL)));
 	klass = VALA_CCODE_ASSIGNMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_ASSIGNMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
