@@ -37,7 +37,7 @@ enum  {
 	VALA_CCODE_BINARY_EXPRESSION_DUMMY_PROPERTY,
 	VALA_CCODE_BINARY_EXPRESSION_OPERATOR,
 	VALA_CCODE_BINARY_EXPRESSION_LEFT,
-	VALA_CCODE_BINARY_EXPRESSION_RIGHT,
+	VALA_CCODE_BINARY_EXPRESSION_RIGHT
 };
 static void vala_ccode_binary_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_binary_expression_parent_class = NULL;
@@ -46,21 +46,25 @@ static void vala_ccode_binary_expression_dispose (GObject * obj);
 
 ValaCCodeBinaryExpression* vala_ccode_binary_expression_new (ValaCCodeBinaryOperator op, ValaCCodeExpression* l, ValaCCodeExpression* r)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeBinaryExpression * self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (l), NULL);
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (r), NULL);
-	GParameter * __params = g_new0 (GParameter, 3);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
 	(__params_it->name = "operator", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, op), __params_it++);
 	(__params_it->name = "left", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, l), __params_it++);
 	(__params_it->name = "right", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, r), __params_it++);
-	ValaCCodeBinaryExpression * self = g_object_newv (VALA_TYPE_CCODE_BINARY_EXPRESSION, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_BINARY_EXPRESSION, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_ccode_binary_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeBinaryExpression * self = VALA_CCODE_BINARY_EXPRESSION (base);
+	ValaCCodeBinaryExpression * self;
+	self = VALA_CCODE_BINARY_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (vala_ccode_binary_expression_get_left (self) != NULL) {
 		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_binary_expression_get_left (self)), writer);
@@ -167,8 +171,9 @@ ValaCCodeExpression* vala_ccode_binary_expression_get_left (ValaCCodeBinaryExpre
 
 void vala_ccode_binary_expression_set_left (ValaCCodeBinaryExpression* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp2;
 	g_return_if_fail (VALA_IS_CCODE_BINARY_EXPRESSION (self));
-	ValaCCodeExpression* __temp2 = NULL;
+	__temp2 = NULL;
 	self->priv->_left = (__temp2 = g_object_ref (value), (self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL))), __temp2);
 }
 
@@ -182,15 +187,17 @@ ValaCCodeExpression* vala_ccode_binary_expression_get_right (ValaCCodeBinaryExpr
 
 void vala_ccode_binary_expression_set_right (ValaCCodeBinaryExpression* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp4;
 	g_return_if_fail (VALA_IS_CCODE_BINARY_EXPRESSION (self));
-	ValaCCodeExpression* __temp4 = NULL;
+	__temp4 = NULL;
 	self->priv->_right = (__temp4 = g_object_ref (value), (self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL))), __temp4);
 }
 
 
 static void vala_ccode_binary_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeBinaryExpression * self = VALA_CCODE_BINARY_EXPRESSION (object);
+	ValaCCodeBinaryExpression * self;
+	self = VALA_CCODE_BINARY_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_CCODE_BINARY_EXPRESSION_OPERATOR:
 		g_value_set_int (value, vala_ccode_binary_expression_get_operator (self));
@@ -207,7 +214,8 @@ static void vala_ccode_binary_expression_get_property (GObject * object, guint p
 
 static void vala_ccode_binary_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeBinaryExpression * self = VALA_CCODE_BINARY_EXPRESSION (object);
+	ValaCCodeBinaryExpression * self;
+	self = VALA_CCODE_BINARY_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_CCODE_BINARY_EXPRESSION_OPERATOR:
 		vala_ccode_binary_expression_set_operator (self, g_value_get_int (value));
@@ -244,11 +252,12 @@ static void vala_ccode_binary_expression_init (ValaCCodeBinaryExpression * self)
 
 static void vala_ccode_binary_expression_dispose (GObject * obj)
 {
-	ValaCCodeBinaryExpression * self = VALA_CCODE_BINARY_EXPRESSION (obj);
-	(self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL)));
-	(self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL)));
+	ValaCCodeBinaryExpression * self;
 	ValaCCodeBinaryExpressionClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_BINARY_EXPRESSION (obj);
+	(self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL)));
+	(self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL)));
 	klass = VALA_CCODE_BINARY_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_BINARY_EXPRESSION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
