@@ -26,11 +26,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-struct _ValaCCodeBreakStatementPrivate {
-};
-#define VALA_CCODE_BREAK_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_BREAK_STATEMENT, ValaCCodeBreakStatementPrivate))
 enum  {
-	VALA_CCODE_BREAK_STATEMENT_DUMMY_PROPERTY,
+	VALA_CCODE_BREAK_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_ccode_break_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_break_statement_parent_class = NULL;
@@ -38,7 +35,8 @@ static gpointer vala_ccode_break_statement_parent_class = NULL;
 
 static void vala_ccode_break_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeBreakStatement * self = VALA_CCODE_BREAK_STATEMENT (base);
+	ValaCCodeBreakStatement * self;
+	self = VALA_CCODE_BREAK_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "break;");
@@ -46,27 +44,9 @@ static void vala_ccode_break_statement_real_write (ValaCCodeNode* base, ValaCCod
 }
 
 
-static void vala_ccode_break_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
-	ValaCCodeBreakStatement * self = VALA_CCODE_BREAK_STATEMENT (object);
-	switch (property_id) {
-	}
-}
-
-
-static void vala_ccode_break_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
-	ValaCCodeBreakStatement * self = VALA_CCODE_BREAK_STATEMENT (object);
-	switch (property_id) {
-	}
-}
-
-
 static void vala_ccode_break_statement_class_init (ValaCCodeBreakStatementClass * klass)
 {
 	vala_ccode_break_statement_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_break_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_break_statement_set_property;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_break_statement_real_write;
 }
 
