@@ -33,7 +33,7 @@ struct _ValaCCodeFormalParameterPrivate {
 enum  {
 	VALA_CCODE_FORMAL_PARAMETER_DUMMY_PROPERTY,
 	VALA_CCODE_FORMAL_PARAMETER_NAME,
-	VALA_CCODE_FORMAL_PARAMETER_TYPE_NAME,
+	VALA_CCODE_FORMAL_PARAMETER_TYPE_NAME
 };
 static void vala_ccode_formal_parameter_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_formal_parameter_parent_class = NULL;
@@ -42,20 +42,24 @@ static void vala_ccode_formal_parameter_dispose (GObject * obj);
 
 ValaCCodeFormalParameter* vala_ccode_formal_parameter_new (const char* n, const char* type)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeFormalParameter * self;
 	g_return_val_if_fail (n != NULL, NULL);
 	g_return_val_if_fail (type != NULL, NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, n), __params_it++);
 	(__params_it->name = "type-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, type), __params_it++);
-	ValaCCodeFormalParameter * self = g_object_newv (VALA_TYPE_CCODE_FORMAL_PARAMETER, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_FORMAL_PARAMETER, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_ccode_formal_parameter_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeFormalParameter * self = VALA_CCODE_FORMAL_PARAMETER (base);
+	ValaCCodeFormalParameter * self;
+	self = VALA_CCODE_FORMAL_PARAMETER (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, vala_ccode_formal_parameter_get_type_name (self));
 	vala_ccode_writer_write_string (writer, " ");
@@ -72,8 +76,9 @@ char* vala_ccode_formal_parameter_get_name (ValaCCodeFormalParameter* self)
 
 void vala_ccode_formal_parameter_set_name (ValaCCodeFormalParameter* self, const char* value)
 {
+	char* __temp1;
 	g_return_if_fail (VALA_IS_CCODE_FORMAL_PARAMETER (self));
-	char* __temp1 = NULL;
+	__temp1 = NULL;
 	self->priv->_name = (__temp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp1);
 }
 
@@ -87,15 +92,17 @@ char* vala_ccode_formal_parameter_get_type_name (ValaCCodeFormalParameter* self)
 
 void vala_ccode_formal_parameter_set_type_name (ValaCCodeFormalParameter* self, const char* value)
 {
+	char* __temp3;
 	g_return_if_fail (VALA_IS_CCODE_FORMAL_PARAMETER (self));
-	char* __temp3 = NULL;
+	__temp3 = NULL;
 	self->priv->_type_name = (__temp3 = g_strdup (value), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), __temp3);
 }
 
 
 static void vala_ccode_formal_parameter_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeFormalParameter * self = VALA_CCODE_FORMAL_PARAMETER (object);
+	ValaCCodeFormalParameter * self;
+	self = VALA_CCODE_FORMAL_PARAMETER (object);
 	switch (property_id) {
 		case VALA_CCODE_FORMAL_PARAMETER_NAME:
 		g_value_set_string (value, vala_ccode_formal_parameter_get_name (self));
@@ -109,7 +116,8 @@ static void vala_ccode_formal_parameter_get_property (GObject * object, guint pr
 
 static void vala_ccode_formal_parameter_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeFormalParameter * self = VALA_CCODE_FORMAL_PARAMETER (object);
+	ValaCCodeFormalParameter * self;
+	self = VALA_CCODE_FORMAL_PARAMETER (object);
 	switch (property_id) {
 		case VALA_CCODE_FORMAL_PARAMETER_NAME:
 		vala_ccode_formal_parameter_set_name (self, g_value_get_string (value));
@@ -142,11 +150,12 @@ static void vala_ccode_formal_parameter_init (ValaCCodeFormalParameter * self)
 
 static void vala_ccode_formal_parameter_dispose (GObject * obj)
 {
-	ValaCCodeFormalParameter * self = VALA_CCODE_FORMAL_PARAMETER (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	(self->priv->_type_name = (g_free (self->priv->_type_name), NULL));
+	ValaCCodeFormalParameter * self;
 	ValaCCodeFormalParameterClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_FORMAL_PARAMETER (obj);
+	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	(self->priv->_type_name = (g_free (self->priv->_type_name), NULL));
 	klass = VALA_CCODE_FORMAL_PARAMETER_CLASS (g_type_class_peek (VALA_TYPE_CCODE_FORMAL_PARAMETER));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
