@@ -1,6 +1,6 @@
 /* valaccodefragment.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,9 +30,10 @@ struct _ValaCCodeFragmentPrivate {
 };
 #define VALA_CCODE_FRAGMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FRAGMENT, ValaCCodeFragmentPrivate))
 enum  {
-	VALA_CCODE_FRAGMENT_DUMMY_PROPERTY,
+	VALA_CCODE_FRAGMENT_DUMMY_PROPERTY
 };
 static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
+static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_fragment_parent_class = NULL;
 static void vala_ccode_fragment_dispose (GObject * obj);
 
@@ -64,14 +65,17 @@ GList* vala_ccode_fragment_get_children (ValaCCodeFragment* self)
 
 static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeFragment * self = VALA_CCODE_FRAGMENT (base);
+	ValaCCodeFragment * self;
+	self = VALA_CCODE_FRAGMENT (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
-		GList* __temp1 = NULL;
-		__temp1 = self->priv->children;
+		GList* __temp1;
 		GList* node_it;
+		__temp1 = NULL;
+		__temp1 = self->priv->children;
 		for (node_it = __temp1; node_it != NULL; node_it = node_it->next) {
-			ValaCCodeNode* node = node_it->data;
+			ValaCCodeNode* node;
+			node = node_it->data;
 			{
 				vala_ccode_node_write (node, writer);
 			}
@@ -80,18 +84,23 @@ static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter
 }
 
 
-static void vala_ccode_fragment_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
+static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeFragment * self = VALA_CCODE_FRAGMENT (object);
-	switch (property_id) {
-	}
-}
-
-
-static void vala_ccode_fragment_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
-	ValaCCodeFragment * self = VALA_CCODE_FRAGMENT (object);
-	switch (property_id) {
+	ValaCCodeFragment * self;
+	self = VALA_CCODE_FRAGMENT (base);
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	{
+		GList* __temp2;
+		GList* node_it;
+		__temp2 = NULL;
+		__temp2 = self->priv->children;
+		for (node_it = __temp2; node_it != NULL; node_it = node_it->next) {
+			ValaCCodeNode* node;
+			node = node_it->data;
+			{
+				vala_ccode_node_write_declaration (node, writer);
+			}
+		}
 	}
 }
 
@@ -100,10 +109,9 @@ static void vala_ccode_fragment_class_init (ValaCCodeFragmentClass * klass)
 {
 	vala_ccode_fragment_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeFragmentPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_fragment_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_fragment_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_fragment_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_fragment_real_write;
+	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_fragment_real_write_declaration;
 }
 
 
@@ -115,10 +123,11 @@ static void vala_ccode_fragment_init (ValaCCodeFragment * self)
 
 static void vala_ccode_fragment_dispose (GObject * obj)
 {
-	ValaCCodeFragment * self = VALA_CCODE_FRAGMENT (obj);
-	(self->priv->children == NULL ? NULL : (self->priv->children = (g_list_foreach (self->priv->children, (GFunc) g_object_unref, NULL), g_list_free (self->priv->children), NULL)));
+	ValaCCodeFragment * self;
 	ValaCCodeFragmentClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_FRAGMENT (obj);
+	(self->priv->children == NULL ? NULL : (self->priv->children = (g_list_foreach (self->priv->children, (GFunc) g_object_unref, NULL), g_list_free (self->priv->children), NULL)));
 	klass = VALA_CCODE_FRAGMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_FRAGMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
