@@ -1,6 +1,6 @@
 /* valaccodefunction.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -37,7 +37,7 @@ enum  {
 	VALA_CCODE_FUNCTION_NAME,
 	VALA_CCODE_FUNCTION_MODIFIERS,
 	VALA_CCODE_FUNCTION_RETURN_TYPE,
-	VALA_CCODE_FUNCTION_BLOCK,
+	VALA_CCODE_FUNCTION_BLOCK
 };
 static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_function_parent_class = NULL;
@@ -46,13 +46,16 @@ static void vala_ccode_function_dispose (GObject * obj);
 
 ValaCCodeFunction* vala_ccode_function_new (const char* _name, const char* _return_type)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeFunction * self;
 	g_return_val_if_fail (_name != NULL, NULL);
 	g_return_val_if_fail (_return_type != NULL, NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
 	(__params_it->name = "return-type", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _return_type), __params_it++);
-	ValaCCodeFunction * self = g_object_newv (VALA_TYPE_CCODE_FUNCTION, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION, __params_it - __params, __params);
 	return self;
 }
 
@@ -77,20 +80,24 @@ void vala_ccode_function_add_parameter (ValaCCodeFunction* self, ValaCCodeFormal
  */
 ValaCCodeFunction* vala_ccode_function_copy (ValaCCodeFunction* self)
 {
+	ValaCCodeFunction* func;
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION (self), NULL);
-	ValaCCodeFunction* func = vala_ccode_function_new (vala_ccode_function_get_name (self), vala_ccode_function_get_return_type (self));
+	func = vala_ccode_function_new (vala_ccode_function_get_name (self), vala_ccode_function_get_return_type (self));
 	(vala_ccode_function_set_modifiers (func, vala_ccode_function_get_modifiers (self)), vala_ccode_function_get_modifiers (func));
 	{
-		GList* __temp1 = NULL;
-		__temp1 = self->priv->parameters;
+		GList* __temp1;
 		GList* param_it;
+		__temp1 = NULL;
+		__temp1 = self->priv->parameters;
 		for (param_it = __temp1; param_it != NULL; param_it = param_it->next) {
-			ValaCCodeFormalParameter* param = param_it->data;
+			ValaCCodeFormalParameter* param;
+			param = param_it->data;
 			{
+				ValaCCodeFormalParameter* __temp0;
 				/* no deep copy for lists available yet
 				 * func.parameters = parameters.copy ();
 				 */
-				ValaCCodeFormalParameter* __temp0 = NULL;
+				__temp0 = NULL;
 				func->priv->parameters = g_list_append (func->priv->parameters, (__temp0 = param, (__temp0 == NULL ? NULL : g_object_ref (__temp0))));
 			}
 		}
@@ -103,7 +110,9 @@ ValaCCodeFunction* vala_ccode_function_copy (ValaCCodeFunction* self)
 
 static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeFunction * self = VALA_CCODE_FUNCTION (base);
+	ValaCCodeFunction * self;
+	gboolean first;
+	self = VALA_CCODE_FUNCTION (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	if ((vala_ccode_function_get_modifiers (self) & VALA_CCODE_MODIFIERS_STATIC) == VALA_CCODE_MODIFIERS_STATIC) {
@@ -113,13 +122,15 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 	vala_ccode_writer_write_string (writer, " ");
 	vala_ccode_writer_write_string (writer, vala_ccode_function_get_name (self));
 	vala_ccode_writer_write_string (writer, " (");
-	gboolean first = TRUE;
+	first = TRUE;
 	{
-		GList* __temp3 = NULL;
-		__temp3 = self->priv->parameters;
+		GList* __temp3;
 		GList* param_it;
+		__temp3 = NULL;
+		__temp3 = self->priv->parameters;
 		for (param_it = __temp3; param_it != NULL; param_it = param_it->next) {
-			ValaCCodeFormalParameter* param = param_it->data;
+			ValaCCodeFormalParameter* param;
+			param = param_it->data;
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -151,8 +162,9 @@ char* vala_ccode_function_get_name (ValaCCodeFunction* self)
 
 void vala_ccode_function_set_name (ValaCCodeFunction* self, const char* value)
 {
+	char* __temp5;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION (self));
-	char* __temp5 = NULL;
+	__temp5 = NULL;
 	self->priv->_name = (__temp5 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp5);
 }
 
@@ -180,8 +192,9 @@ char* vala_ccode_function_get_return_type (ValaCCodeFunction* self)
 
 void vala_ccode_function_set_return_type (ValaCCodeFunction* self, const char* value)
 {
+	char* __temp8;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION (self));
-	char* __temp8 = NULL;
+	__temp8 = NULL;
 	self->priv->_return_type = (__temp8 = g_strdup (value), (self->priv->_return_type = (g_free (self->priv->_return_type), NULL)), __temp8);
 }
 
@@ -195,16 +208,19 @@ ValaCCodeBlock* vala_ccode_function_get_block (ValaCCodeFunction* self)
 
 void vala_ccode_function_set_block (ValaCCodeFunction* self, ValaCCodeBlock* value)
 {
+	ValaCCodeBlock* __temp11;
+	ValaCCodeBlock* __temp10;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION (self));
-	ValaCCodeBlock* __temp11 = NULL;
-	ValaCCodeBlock* __temp10 = NULL;
+	__temp11 = NULL;
+	__temp10 = NULL;
 	self->priv->_block = (__temp11 = (__temp10 = value, (__temp10 == NULL ? NULL : g_object_ref (__temp10))), (self->priv->_block == NULL ? NULL : (self->priv->_block = (g_object_unref (self->priv->_block), NULL))), __temp11);
 }
 
 
 static void vala_ccode_function_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeFunction * self = VALA_CCODE_FUNCTION (object);
+	ValaCCodeFunction * self;
+	self = VALA_CCODE_FUNCTION (object);
 	switch (property_id) {
 		case VALA_CCODE_FUNCTION_NAME:
 		g_value_set_string (value, vala_ccode_function_get_name (self));
@@ -224,7 +240,8 @@ static void vala_ccode_function_get_property (GObject * object, guint property_i
 
 static void vala_ccode_function_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeFunction * self = VALA_CCODE_FUNCTION (object);
+	ValaCCodeFunction * self;
+	self = VALA_CCODE_FUNCTION (object);
 	switch (property_id) {
 		case VALA_CCODE_FUNCTION_NAME:
 		vala_ccode_function_set_name (self, g_value_get_string (value));
@@ -265,13 +282,14 @@ static void vala_ccode_function_init (ValaCCodeFunction * self)
 
 static void vala_ccode_function_dispose (GObject * obj)
 {
-	ValaCCodeFunction * self = VALA_CCODE_FUNCTION (obj);
+	ValaCCodeFunction * self;
+	ValaCCodeFunctionClass * klass;
+	GObjectClass * parent_class;
+	self = VALA_CCODE_FUNCTION (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_return_type = (g_free (self->priv->_return_type), NULL));
 	(self->priv->_block == NULL ? NULL : (self->priv->_block = (g_object_unref (self->priv->_block), NULL)));
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_list_foreach (self->priv->parameters, (GFunc) g_object_unref, NULL), g_list_free (self->priv->parameters), NULL)));
-	ValaCCodeFunctionClass * klass;
-	GObjectClass * parent_class;
 	klass = VALA_CCODE_FUNCTION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_FUNCTION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
