@@ -35,7 +35,7 @@ struct _ValaCCodeFunctionCallPrivate {
 #define VALA_CCODE_FUNCTION_CALL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FUNCTION_CALL, ValaCCodeFunctionCallPrivate))
 enum  {
 	VALA_CCODE_FUNCTION_CALL_DUMMY_PROPERTY,
-	VALA_CCODE_FUNCTION_CALL_CALL,
+	VALA_CCODE_FUNCTION_CALL_CALL
 };
 static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_function_call_parent_class = NULL;
@@ -44,11 +44,14 @@ static void vala_ccode_function_call_dispose (GObject * obj);
 
 ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* _call)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeFunctionCall * self;
 	g_return_val_if_fail (_call == NULL || VALA_IS_CCODE_EXPRESSION (_call), NULL);
-	GParameter * __params = g_new0 (GParameter, 1);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "call", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, _call), __params_it++);
-	ValaCCodeFunctionCall * self = g_object_newv (VALA_TYPE_CCODE_FUNCTION_CALL, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION_CALL, __params_it - __params, __params);
 	return self;
 }
 
@@ -68,17 +71,21 @@ void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCo
 
 static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeFunctionCall * self = VALA_CCODE_FUNCTION_CALL (base);
+	ValaCCodeFunctionCall * self;
+	gboolean first;
+	self = VALA_CCODE_FUNCTION_CALL (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_function_call_get_call (self)), writer);
 	vala_ccode_writer_write_string (writer, " (");
-	gboolean first = TRUE;
+	first = TRUE;
 	{
-		GList* __temp0 = NULL;
-		__temp0 = self->priv->arguments;
+		GList* __temp0;
 		GList* expr_it;
+		__temp0 = NULL;
+		__temp0 = self->priv->arguments;
 		for (expr_it = __temp0; expr_it != NULL; expr_it = expr_it->next) {
-			ValaCCodeExpression* expr = expr_it->data;
+			ValaCCodeExpression* expr;
+			expr = expr_it->data;
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -104,16 +111,19 @@ ValaCCodeExpression* vala_ccode_function_call_get_call (ValaCCodeFunctionCall* s
 
 void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp3;
+	ValaCCodeExpression* __temp2;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self));
-	ValaCCodeExpression* __temp3 = NULL;
-	ValaCCodeExpression* __temp2 = NULL;
+	__temp3 = NULL;
+	__temp2 = NULL;
 	self->priv->_call = (__temp3 = (__temp2 = value, (__temp2 == NULL ? NULL : g_object_ref (__temp2))), (self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL))), __temp3);
 }
 
 
 static void vala_ccode_function_call_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeFunctionCall * self = VALA_CCODE_FUNCTION_CALL (object);
+	ValaCCodeFunctionCall * self;
+	self = VALA_CCODE_FUNCTION_CALL (object);
 	switch (property_id) {
 		case VALA_CCODE_FUNCTION_CALL_CALL:
 		g_value_set_object (value, vala_ccode_function_call_get_call (self));
@@ -124,7 +134,8 @@ static void vala_ccode_function_call_get_property (GObject * object, guint prope
 
 static void vala_ccode_function_call_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeFunctionCall * self = VALA_CCODE_FUNCTION_CALL (object);
+	ValaCCodeFunctionCall * self;
+	self = VALA_CCODE_FUNCTION_CALL (object);
 	switch (property_id) {
 		case VALA_CCODE_FUNCTION_CALL_CALL:
 		vala_ccode_function_call_set_call (self, g_value_get_object (value));
@@ -153,11 +164,12 @@ static void vala_ccode_function_call_init (ValaCCodeFunctionCall * self)
 
 static void vala_ccode_function_call_dispose (GObject * obj)
 {
-	ValaCCodeFunctionCall * self = VALA_CCODE_FUNCTION_CALL (obj);
-	(self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL)));
-	(self->priv->arguments == NULL ? NULL : (self->priv->arguments = (g_list_foreach (self->priv->arguments, (GFunc) g_object_unref, NULL), g_list_free (self->priv->arguments), NULL)));
+	ValaCCodeFunctionCall * self;
 	ValaCCodeFunctionCallClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_FUNCTION_CALL (obj);
+	(self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL)));
+	(self->priv->arguments == NULL ? NULL : (self->priv->arguments = (g_list_foreach (self->priv->arguments, (GFunc) g_object_unref, NULL), g_list_free (self->priv->arguments), NULL)));
 	klass = VALA_CCODE_FUNCTION_CALL_CLASS (g_type_class_peek (VALA_TYPE_CCODE_FUNCTION_CALL));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
