@@ -1,6 +1,6 @@
 /* valaccodenode.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,11 @@
 
 #ifndef __VALACCODENODE_H__
 #define __VALACCODENODE_H__
+typedef struct _ValaCCodeNode ValaCCodeNode;
+typedef struct _ValaCCodeNodeClass ValaCCodeNodeClass;
+typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
+typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
+typedef struct _ValaCCodeNodePrivate ValaCCodeNodePrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -29,10 +34,6 @@
 
 G_BEGIN_DECLS
 
-typedef struct _ValaCCodeNode ValaCCodeNode;
-typedef struct _ValaCCodeNodeClass ValaCCodeNodeClass;
-typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
-typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
 #define VALA_TYPE_CCODE_NODE (vala_ccode_node_get_type ())
 #define VALA_CCODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_NODE, ValaCCodeNode))
@@ -41,7 +42,6 @@ typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 #define VALA_IS_CCODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_NODE))
 #define VALA_CCODE_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_NODE, ValaCCodeNodeClass))
 
-typedef struct _ValaCCodeNodePrivate ValaCCodeNodePrivate;
 
 /**
  * Represents a node in the C code tree.
@@ -53,9 +53,11 @@ struct _ValaCCodeNode {
 struct _ValaCCodeNodeClass {
 	GObjectClass parent;
 	void (*write) (ValaCCodeNode* self, ValaCCodeWriter* writer);
+	void (*write_declaration) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
+void vala_ccode_node_write_declaration (ValaCCodeNode* self, ValaCCodeWriter* writer);
 ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
 void vala_ccode_node_set_line (ValaCCodeNode* self, ValaCCodeLineDirective* value);
 GType vala_ccode_node_get_type ();
