@@ -36,7 +36,7 @@ struct _ValaCCodeWhileStatementPrivate {
 enum  {
 	VALA_CCODE_WHILE_STATEMENT_DUMMY_PROPERTY,
 	VALA_CCODE_WHILE_STATEMENT_CONDITION,
-	VALA_CCODE_WHILE_STATEMENT_BODY,
+	VALA_CCODE_WHILE_STATEMENT_BODY
 };
 static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_while_statement_parent_class = NULL;
@@ -45,20 +45,24 @@ static void vala_ccode_while_statement_dispose (GObject * obj);
 
 ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* stmt)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeWhileStatement * self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
 	g_return_val_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "condition", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, cond), __params_it++);
 	(__params_it->name = "body", g_value_init (&__params_it->value, VALA_TYPE_CCODE_STATEMENT), g_value_set_object (&__params_it->value, stmt), __params_it++);
-	ValaCCodeWhileStatement * self = g_object_newv (VALA_TYPE_CCODE_WHILE_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_WHILE_STATEMENT, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeWhileStatement * self = VALA_CCODE_WHILE_STATEMENT (base);
+	ValaCCodeWhileStatement * self;
+	self = VALA_CCODE_WHILE_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "while (");
@@ -77,8 +81,9 @@ ValaCCodeExpression* vala_ccode_while_statement_get_condition (ValaCCodeWhileSta
 
 void vala_ccode_while_statement_set_condition (ValaCCodeWhileStatement* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp1;
 	g_return_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self));
-	ValaCCodeExpression* __temp1 = NULL;
+	__temp1 = NULL;
 	self->priv->_condition = (__temp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), __temp1);
 }
 
@@ -92,16 +97,19 @@ ValaCCodeStatement* vala_ccode_while_statement_get_body (ValaCCodeWhileStatement
 
 void vala_ccode_while_statement_set_body (ValaCCodeWhileStatement* self, ValaCCodeStatement* value)
 {
+	ValaCCodeStatement* __temp4;
+	ValaCCodeStatement* __temp3;
 	g_return_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self));
-	ValaCCodeStatement* __temp4 = NULL;
-	ValaCCodeStatement* __temp3 = NULL;
+	__temp4 = NULL;
+	__temp3 = NULL;
 	self->priv->_body = (__temp4 = (__temp3 = value, (__temp3 == NULL ? NULL : g_object_ref (__temp3))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp4);
 }
 
 
 static void vala_ccode_while_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeWhileStatement * self = VALA_CCODE_WHILE_STATEMENT (object);
+	ValaCCodeWhileStatement * self;
+	self = VALA_CCODE_WHILE_STATEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_WHILE_STATEMENT_CONDITION:
 		g_value_set_object (value, vala_ccode_while_statement_get_condition (self));
@@ -115,7 +123,8 @@ static void vala_ccode_while_statement_get_property (GObject * object, guint pro
 
 static void vala_ccode_while_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeWhileStatement * self = VALA_CCODE_WHILE_STATEMENT (object);
+	ValaCCodeWhileStatement * self;
+	self = VALA_CCODE_WHILE_STATEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_WHILE_STATEMENT_CONDITION:
 		vala_ccode_while_statement_set_condition (self, g_value_get_object (value));
@@ -148,11 +157,12 @@ static void vala_ccode_while_statement_init (ValaCCodeWhileStatement * self)
 
 static void vala_ccode_while_statement_dispose (GObject * obj)
 {
-	ValaCCodeWhileStatement * self = VALA_CCODE_WHILE_STATEMENT (obj);
-	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
+	ValaCCodeWhileStatement * self;
 	ValaCCodeWhileStatementClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_WHILE_STATEMENT (obj);
+	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	klass = VALA_CCODE_WHILE_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_WHILE_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
