@@ -42,7 +42,7 @@ struct _ValaDataTypePrivate {
 #define VALA_DATA_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DATA_TYPE, ValaDataTypePrivate))
 enum  {
 	VALA_DATA_TYPE_DUMMY_PROPERTY,
-	VALA_DATA_TYPE_NAME,
+	VALA_DATA_TYPE_NAME
 };
 static gboolean vala_data_type_real_is_reference_type (ValaDataType* self);
 static char* vala_data_type_real_get_dup_function (ValaDataType* self);
@@ -359,11 +359,13 @@ static GList* vala_data_type_real_get_cheader_filenames (ValaDataType* self)
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
 	if (self->priv->cheader_filenames == NULL) {
 		{
-			GList* __temp14 = NULL;
-			__temp14 = vala_namespace_get_cheader_filenames (self->namespace);
+			GList* __temp14;
 			GList* filename_it;
+			__temp14 = NULL;
+			__temp14 = vala_namespace_get_cheader_filenames (self->namespace);
 			for (filename_it = __temp14; filename_it != NULL; filename_it = filename_it->next) {
-				char* filename = filename_it->data;
+				char* filename;
+				filename = filename_it->data;
 				{
 					/* default to header filenames of the namespace */
 					vala_data_type_add_cheader_filename (self, filename);
@@ -403,19 +405,22 @@ void vala_data_type_add_cheader_filename (ValaDataType* self, const char* filena
  */
 ValaPointer* vala_data_type_get_pointer (ValaDataType* self)
 {
+	ValaPointer* __temp18;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
 	if (self->priv->pointer_type == NULL) {
-		ValaPointer* __temp16 = NULL;
+		ValaPointer* __temp16;
+		ValaSymbol* __temp17;
+		__temp16 = NULL;
 		self->priv->pointer_type = (__temp16 = vala_pointer_new (self, vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->pointer_type == NULL ? NULL : (self->priv->pointer_type = (g_object_unref (self->priv->pointer_type), NULL))), __temp16);
 		/* create a new Symbol */
-		ValaSymbol* __temp17 = NULL;
+		__temp17 = NULL;
 		(vala_code_node_set_symbol (VALA_CODE_NODE (self->priv->pointer_type), (__temp17 = vala_symbol_new (VALA_CODE_NODE (self->priv->pointer_type)))), vala_code_node_get_symbol (VALA_CODE_NODE (self->priv->pointer_type)));
 		(__temp17 == NULL ? NULL : (__temp17 = (g_object_unref (__temp17), NULL)));
 		vala_symbol_add (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self))), vala_data_type_get_name (VALA_DATA_TYPE (self->priv->pointer_type)), vala_code_node_get_symbol (VALA_CODE_NODE (self->priv->pointer_type)));
 		/* link the namespace */
 		VALA_DATA_TYPE (self->priv->pointer_type)->namespace = self->namespace;
 	}
-	ValaPointer* __temp18 = NULL;
+	__temp18 = NULL;
 	return (__temp18 = self->priv->pointer_type, (__temp18 == NULL ? NULL : g_object_ref (__temp18)));
 }
 
@@ -428,27 +433,40 @@ ValaPointer* vala_data_type_get_pointer (ValaDataType* self)
  */
 ValaArray* vala_data_type_get_array (ValaDataType* self, gint rank)
 {
+	ValaArray* __temp21;
+	char* __temp20;
+	ValaArray* __temp22;
+	ValaArray* array_type;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
-	ValaArray* __temp21 = NULL;
-	char* __temp20 = NULL;
-	ValaArray* __temp22 = NULL;
-	ValaArray* array_type = (__temp22 = (__temp21 = VALA_ARRAY (g_hash_table_lookup (self->priv->array_types, (__temp20 = g_strdup_printf ("%i", rank)))), (__temp21 == NULL ? NULL : g_object_ref (__temp21))), (__temp20 = (g_free (__temp20), NULL)), __temp22);
+	__temp21 = NULL;
+	__temp20 = NULL;
+	__temp22 = NULL;
+	array_type = (__temp22 = (__temp21 = VALA_ARRAY (g_hash_table_lookup (self->priv->array_types, (__temp20 = g_strdup_printf ("%i", rank)))), (__temp21 == NULL ? NULL : g_object_ref (__temp21))), (__temp20 = (g_free (__temp20), NULL)), __temp22);
 	if (array_type == NULL) {
-		ValaArray* new_array_type = vala_array_new (self, rank, vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
+		ValaArray* new_array_type;
+		ValaSymbol* __temp23;
+		ValaArrayLengthField* __temp25;
+		ValaArrayLengthField* __temp24;
+		ValaArrayResizeMethod* __temp27;
+		ValaArrayResizeMethod* __temp26;
+		ValaArray* __temp28;
+		ValaArray* __temp30;
+		ValaArray* __temp29;
+		new_array_type = vala_array_new (self, rank, vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
 		/* create a new Symbol */
-		ValaSymbol* __temp23 = NULL;
+		__temp23 = NULL;
 		(vala_code_node_set_symbol (VALA_CODE_NODE (new_array_type), (__temp23 = vala_symbol_new (VALA_CODE_NODE (new_array_type)))), vala_code_node_get_symbol (VALA_CODE_NODE (new_array_type)));
 		(__temp23 == NULL ? NULL : (__temp23 = (g_object_unref (__temp23), NULL)));
 		vala_symbol_add (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self))), vala_data_type_get_name (VALA_DATA_TYPE (new_array_type)), vala_code_node_get_symbol (VALA_CODE_NODE (new_array_type)));
 		/* add internal length field */
-		ValaArrayLengthField* __temp25 = NULL;
-		ValaArrayLengthField* __temp24 = NULL;
+		__temp25 = NULL;
+		__temp24 = NULL;
 		vala_symbol_add (vala_code_node_get_symbol (VALA_CODE_NODE (new_array_type)), vala_field_get_name (VALA_FIELD ((__temp24 = vala_array_get_length_field (new_array_type)))), vala_code_node_get_symbol (VALA_CODE_NODE ((__temp25 = vala_array_get_length_field (new_array_type)))));
 		(__temp25 == NULL ? NULL : (__temp25 = (g_object_unref (__temp25), NULL)));
 		(__temp24 == NULL ? NULL : (__temp24 = (g_object_unref (__temp24), NULL)));
 		/* add internal resize method */
-		ValaArrayResizeMethod* __temp27 = NULL;
-		ValaArrayResizeMethod* __temp26 = NULL;
+		__temp27 = NULL;
+		__temp26 = NULL;
 		vala_symbol_add (vala_code_node_get_symbol (VALA_CODE_NODE (new_array_type)), vala_method_get_name (VALA_METHOD ((__temp26 = vala_array_get_resize_method (new_array_type)))), vala_code_node_get_symbol (VALA_CODE_NODE ((__temp27 = vala_array_get_resize_method (new_array_type)))));
 		(__temp27 == NULL ? NULL : (__temp27 = (g_object_unref (__temp27), NULL)));
 		(__temp26 == NULL ? NULL : (__temp26 = (g_object_unref (__temp26), NULL)));
@@ -456,10 +474,10 @@ ValaArray* vala_data_type_get_array (ValaDataType* self, gint rank)
 		(vala_code_node_set_source_reference (VALA_CODE_NODE (new_array_type), vala_code_node_get_source_reference (VALA_CODE_NODE (self))), vala_code_node_get_source_reference (VALA_CODE_NODE (new_array_type)));
 		/* link the namespace */
 		VALA_DATA_TYPE (new_array_type)->namespace = self->namespace;
-		ValaArray* __temp28 = NULL;
+		__temp28 = NULL;
 		g_hash_table_insert (self->priv->array_types, g_strdup_printf ("%i", rank), (__temp28 = new_array_type, (__temp28 == NULL ? NULL : g_object_ref (__temp28))));
-		ValaArray* __temp30 = NULL;
-		ValaArray* __temp29 = NULL;
+		__temp30 = NULL;
+		__temp29 = NULL;
 		array_type = (__temp30 = (__temp29 = new_array_type, (__temp29 == NULL ? NULL : g_object_ref (__temp29))), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), __temp30);
 		(new_array_type == NULL ? NULL : (new_array_type = (g_object_unref (new_array_type), NULL)));
 	}
@@ -515,16 +533,19 @@ char* vala_data_type_get_name (ValaDataType* self)
 
 void vala_data_type_set_name (ValaDataType* self, const char* value)
 {
+	char* __temp36;
+	const char* __temp35;
 	g_return_if_fail (VALA_IS_DATA_TYPE (self));
-	char* __temp36 = NULL;
-	const char* __temp35 = NULL;
+	__temp36 = NULL;
+	__temp35 = NULL;
 	self->priv->_name = (__temp36 = (__temp35 = value, (__temp35 == NULL ? NULL : g_strdup (__temp35))), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp36);
 }
 
 
 static void vala_data_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaDataType * self = VALA_DATA_TYPE (object);
+	ValaDataType * self;
+	self = VALA_DATA_TYPE (object);
 	switch (property_id) {
 		case VALA_DATA_TYPE_NAME:
 		g_value_set_string (value, vala_data_type_get_name (self));
@@ -535,7 +556,8 @@ static void vala_data_type_get_property (GObject * object, guint property_id, GV
 
 static void vala_data_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaDataType * self = VALA_DATA_TYPE (object);
+	ValaDataType * self;
+	self = VALA_DATA_TYPE (object);
 	switch (property_id) {
 		case VALA_DATA_TYPE_NAME:
 		vala_data_type_set_name (self, g_value_get_string (value));
@@ -581,13 +603,14 @@ static void vala_data_type_init (ValaDataType * self)
 
 static void vala_data_type_dispose (GObject * obj)
 {
-	ValaDataType * self = VALA_DATA_TYPE (obj);
+	ValaDataType * self;
+	ValaDataTypeClass * klass;
+	GObjectClass * parent_class;
+	self = VALA_DATA_TYPE (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_list_foreach (self->priv->cheader_filenames, (GFunc) g_free, NULL), g_list_free (self->priv->cheader_filenames), NULL)));
 	(self->priv->pointer_type == NULL ? NULL : (self->priv->pointer_type = (g_object_unref (self->priv->pointer_type), NULL)));
 	(self->priv->array_types == NULL ? NULL : (self->priv->array_types = (g_hash_table_unref (self->priv->array_types), NULL)));
-	ValaDataTypeClass * klass;
-	GObjectClass * parent_class;
 	klass = VALA_DATA_TYPE_CLASS (g_type_class_peek (VALA_TYPE_DATA_TYPE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
