@@ -38,7 +38,7 @@ struct _ValaExpressionStatementPrivate {
 #define VALA_EXPRESSION_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_EXPRESSION_STATEMENT, ValaExpressionStatementPrivate))
 enum  {
 	VALA_EXPRESSION_STATEMENT_DUMMY_PROPERTY,
-	VALA_EXPRESSION_STATEMENT_EXPRESSION,
+	VALA_EXPRESSION_STATEMENT_EXPRESSION
 };
 static void vala_expression_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_expression_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
@@ -56,20 +56,24 @@ static void vala_expression_statement_dispose (GObject * obj);
  */
 ValaExpressionStatement* vala_expression_statement_new (ValaExpression* expr, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaExpressionStatement * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (expr), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "expression", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaExpressionStatement * self = g_object_newv (VALA_TYPE_EXPRESSION_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_EXPRESSION_STATEMENT, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_expression_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaExpressionStatement * self = VALA_EXPRESSION_STATEMENT (base);
+	ValaExpressionStatement * self;
+	self = VALA_EXPRESSION_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_expression_statement_get_expression (self)), visitor);
 	vala_code_visitor_visit_expression_statement (visitor, self);
@@ -78,7 +82,8 @@ static void vala_expression_statement_real_accept (ValaCodeNode* base, ValaCodeV
 
 static void vala_expression_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
-	ValaExpressionStatement * self = VALA_EXPRESSION_STATEMENT (base);
+	ValaExpressionStatement * self;
+	self = VALA_EXPRESSION_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_expression_statement_get_expression (self)) == old_node) {
@@ -89,18 +94,25 @@ static void vala_expression_statement_real_replace (ValaCodeNode* base, ValaCode
 
 static gint vala_expression_statement_real_get_number_of_set_construction_parameters (ValaStatement* base)
 {
-	ValaExpressionStatement * self = VALA_EXPRESSION_STATEMENT (base);
+	ValaExpressionStatement * self;
+	self = VALA_EXPRESSION_STATEMENT (base);
 	if (VALA_IS_ASSIGNMENT (vala_expression_statement_get_expression (self))) {
-		ValaAssignment* __temp0 = NULL;
-		ValaAssignment* assign = (__temp0 = VALA_ASSIGNMENT (vala_expression_statement_get_expression (self)), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
+		ValaAssignment* __temp0;
+		ValaAssignment* assign;
+		__temp0 = NULL;
+		assign = (__temp0 = VALA_ASSIGNMENT (vala_expression_statement_get_expression (self)), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
 		if (VALA_IS_MEMBER_ACCESS (vala_assignment_get_left (assign))) {
-			ValaMemberAccess* __temp1 = NULL;
-			ValaMemberAccess* ma = (__temp1 = VALA_MEMBER_ACCESS (vala_assignment_get_left (assign)), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
+			ValaMemberAccess* __temp1;
+			ValaMemberAccess* ma;
+			__temp1 = NULL;
+			ma = (__temp1 = VALA_MEMBER_ACCESS (vala_assignment_get_left (assign)), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
 			if (vala_expression_get_symbol_reference (VALA_EXPRESSION (ma)) != NULL) {
 				if (VALA_IS_PROPERTY (vala_symbol_get_node (vala_expression_get_symbol_reference (VALA_EXPRESSION (ma))))) {
-					ValaProperty* __temp2 = NULL;
-					ValaProperty* prop = (__temp2 = VALA_PROPERTY (vala_symbol_get_node (vala_expression_get_symbol_reference (VALA_EXPRESSION (ma)))), (__temp2 == NULL ? NULL : g_object_ref (__temp2)));
+					ValaProperty* __temp2;
+					ValaProperty* prop;
 					gint __temp3;
+					__temp2 = NULL;
+					prop = (__temp2 = VALA_PROPERTY (vala_symbol_get_node (vala_expression_get_symbol_reference (VALA_EXPRESSION (ma)))), (__temp2 == NULL ? NULL : g_object_ref (__temp2)));
 					return (__temp3 = 1, (prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL))), __temp3);
 					(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
 				}
@@ -122,8 +134,9 @@ ValaExpression* vala_expression_statement_get_expression (ValaExpressionStatemen
 
 void vala_expression_statement_set_expression (ValaExpressionStatement* self, ValaExpression* value)
 {
+	ValaExpression* __temp6;
 	g_return_if_fail (VALA_IS_EXPRESSION_STATEMENT (self));
-	ValaExpression* __temp6 = NULL;
+	__temp6 = NULL;
 	self->priv->_expression = (__temp6 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), __temp6);
 	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_expression), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_expression)));
 }
@@ -131,7 +144,8 @@ void vala_expression_statement_set_expression (ValaExpressionStatement* self, Va
 
 static void vala_expression_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaExpressionStatement * self = VALA_EXPRESSION_STATEMENT (object);
+	ValaExpressionStatement * self;
+	self = VALA_EXPRESSION_STATEMENT (object);
 	switch (property_id) {
 		case VALA_EXPRESSION_STATEMENT_EXPRESSION:
 		g_value_set_object (value, vala_expression_statement_get_expression (self));
@@ -142,7 +156,8 @@ static void vala_expression_statement_get_property (GObject * object, guint prop
 
 static void vala_expression_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaExpressionStatement * self = VALA_EXPRESSION_STATEMENT (object);
+	ValaExpressionStatement * self;
+	self = VALA_EXPRESSION_STATEMENT (object);
 	switch (property_id) {
 		case VALA_EXPRESSION_STATEMENT_EXPRESSION:
 		vala_expression_statement_set_expression (self, g_value_get_object (value));
@@ -173,10 +188,11 @@ static void vala_expression_statement_init (ValaExpressionStatement * self)
 
 static void vala_expression_statement_dispose (GObject * obj)
 {
-	ValaExpressionStatement * self = VALA_EXPRESSION_STATEMENT (obj);
-	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
+	ValaExpressionStatement * self;
 	ValaExpressionStatementClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_EXPRESSION_STATEMENT (obj);
+	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
 	klass = VALA_EXPRESSION_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_EXPRESSION_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
