@@ -33,7 +33,7 @@ typedef enum  {
 	VALA_MEMBER_ACCESSIBILITY_PRIVATE,
 	VALA_MEMBER_ACCESSIBILITY_INTERNAL,
 	VALA_MEMBER_ACCESSIBILITY_PROTECTED,
-	VALA_MEMBER_ACCESSIBILITY_PUBLIC,
+	VALA_MEMBER_ACCESSIBILITY_PUBLIC
 } ValaMemberAccessibility;
 
 
