@@ -1,6 +1,6 @@
 /* valanullliteral.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,11 +27,8 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valanullliteral.h>
 
-struct _ValaNullLiteralPrivate {
-};
-#define VALA_NULL_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_NULL_LITERAL, ValaNullLiteralPrivate))
 enum  {
-	VALA_NULL_LITERAL_DUMMY_PROPERTY,
+	VALA_NULL_LITERAL_DUMMY_PROPERTY
 };
 static void vala_null_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_null_literal_real_to_string (ValaCodeNode* base);
@@ -46,18 +43,22 @@ static gpointer vala_null_literal_parent_class = NULL;
  */
 ValaNullLiteral* vala_null_literal_new (ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaNullLiteral * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 1);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaNullLiteral * self = g_object_newv (VALA_TYPE_NULL_LITERAL, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_NULL_LITERAL, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_null_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaNullLiteral * self = VALA_NULL_LITERAL (base);
+	ValaNullLiteral * self;
+	self = VALA_NULL_LITERAL (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_null_literal (visitor, self);
 }
@@ -65,32 +66,15 @@ static void vala_null_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 
 static char* vala_null_literal_real_to_string (ValaCodeNode* base)
 {
-	ValaNullLiteral * self = VALA_NULL_LITERAL (base);
+	ValaNullLiteral * self;
+	self = VALA_NULL_LITERAL (base);
 	return g_strdup ("null");
 }
 
 
-static void vala_null_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
-	ValaNullLiteral * self = VALA_NULL_LITERAL (object);
-	switch (property_id) {
-	}
-}
-
-
-static void vala_null_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
-	ValaNullLiteral * self = VALA_NULL_LITERAL (object);
-	switch (property_id) {
-	}
-}
-
-
 static void vala_null_literal_class_init (ValaNullLiteralClass * klass)
 {
 	vala_null_literal_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->get_property = vala_null_literal_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_null_literal_set_property;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_null_literal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_null_literal_real_to_string;
 }
