@@ -1,6 +1,6 @@
 /* valasourcereference.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -42,7 +42,7 @@ enum  {
 	VALA_SOURCE_REFERENCE_FIRST_COLUMN,
 	VALA_SOURCE_REFERENCE_LAST_LINE,
 	VALA_SOURCE_REFERENCE_LAST_COLUMN,
-	VALA_SOURCE_REFERENCE_COMMENT,
+	VALA_SOURCE_REFERENCE_COMMENT
 };
 static gpointer vala_source_reference_parent_class = NULL;
 static void vala_source_reference_dispose (GObject * obj);
@@ -60,15 +60,18 @@ static void vala_source_reference_dispose (GObject * obj);
  */
 ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaSourceReference * self;
 	g_return_val_if_fail (_file == NULL || VALA_IS_SOURCE_FILE (_file), NULL);
-	GParameter * __params = g_new0 (GParameter, 5);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 5);
+	__params_it = __params;
 	(__params_it->name = "file", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE), g_value_set_object (&__params_it->value, _file), __params_it++);
 	(__params_it->name = "first-line", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _first_line), __params_it++);
 	(__params_it->name = "first-column", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _first_column), __params_it++);
 	(__params_it->name = "last-line", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _last_line), __params_it++);
 	(__params_it->name = "last-column", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _last_column), __params_it++);
-	ValaSourceReference * self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, __params_it - __params, __params);
 	return self;
 }
 
@@ -86,16 +89,19 @@ ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _fir
  */
 ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column, const char* _comment)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaSourceReference * self;
 	g_return_val_if_fail (_file == NULL || VALA_IS_SOURCE_FILE (_file), NULL);
-	GParameter * __params = g_new0 (GParameter, 6);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 6);
+	__params_it = __params;
 	(__params_it->name = "file", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE), g_value_set_object (&__params_it->value, _file), __params_it++);
 	(__params_it->name = "first-line", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _first_line), __params_it++);
 	(__params_it->name = "first-column", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _first_column), __params_it++);
 	(__params_it->name = "last-line", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _last_line), __params_it++);
 	(__params_it->name = "last-column", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _last_column), __params_it++);
 	(__params_it->name = "comment", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _comment), __params_it++);
-	ValaSourceReference * self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, __params_it - __params, __params);
 	return self;
 }
 
@@ -191,16 +197,19 @@ char* vala_source_reference_get_comment (ValaSourceReference* self)
 
 void vala_source_reference_set_comment (ValaSourceReference* self, const char* value)
 {
+	char* __temp8;
+	const char* __temp7;
 	g_return_if_fail (VALA_IS_SOURCE_REFERENCE (self));
-	char* __temp8 = NULL;
-	const char* __temp7 = NULL;
+	__temp8 = NULL;
+	__temp7 = NULL;
 	self->priv->_comment = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_strdup (__temp7))), (self->priv->_comment = (g_free (self->priv->_comment), NULL)), __temp8);
 }
 
 
 static void vala_source_reference_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaSourceReference * self = VALA_SOURCE_REFERENCE (object);
+	ValaSourceReference * self;
+	self = VALA_SOURCE_REFERENCE (object);
 	switch (property_id) {
 		case VALA_SOURCE_REFERENCE_FILE:
 		g_value_set_object (value, vala_source_reference_get_file (self));
@@ -226,7 +235,8 @@ static void vala_source_reference_get_property (GObject * object, guint property
 
 static void vala_source_reference_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaSourceReference * self = VALA_SOURCE_REFERENCE (object);
+	ValaSourceReference * self;
+	self = VALA_SOURCE_REFERENCE (object);
 	switch (property_id) {
 		case VALA_SOURCE_REFERENCE_FILE:
 		vala_source_reference_set_file (self, g_value_get_object (value));
@@ -274,10 +284,11 @@ static void vala_source_reference_init (ValaSourceReference * self)
 
 static void vala_source_reference_dispose (GObject * obj)
 {
-	ValaSourceReference * self = VALA_SOURCE_REFERENCE (obj);
-	(self->priv->_comment = (g_free (self->priv->_comment), NULL));
+	ValaSourceReference * self;
 	ValaSourceReferenceClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_SOURCE_REFERENCE (obj);
+	(self->priv->_comment = (g_free (self->priv->_comment), NULL));
 	klass = VALA_SOURCE_REFERENCE_CLASS (g_type_class_peek (VALA_TYPE_SOURCE_REFERENCE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
