@@ -24,11 +24,8 @@
 
 #include "valastatement.h"
 
-struct _ValaStatementPrivate {
-};
-#define VALA_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STATEMENT, ValaStatementPrivate))
 enum  {
-	VALA_STATEMENT_DUMMY_PROPERTY,
+	VALA_STATEMENT_DUMMY_PROPERTY
 };
 static gint vala_statement_real_get_number_of_set_construction_parameters (ValaStatement* self);
 static gpointer vala_statement_parent_class = NULL;
@@ -54,27 +51,9 @@ gint vala_statement_get_number_of_set_construction_parameters (ValaStatement* se
 }
 
 
-static void vala_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
-	ValaStatement * self = VALA_STATEMENT (object);
-	switch (property_id) {
-	}
-}
-
-
-static void vala_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
-	ValaStatement * self = VALA_STATEMENT (object);
-	switch (property_id) {
-	}
-}
-
-
 static void vala_statement_class_init (ValaStatementClass * klass)
 {
 	vala_statement_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->get_property = vala_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_statement_set_property;
 	VALA_STATEMENT_CLASS (klass)->get_number_of_set_construction_parameters = vala_statement_real_get_number_of_set_construction_parameters;
 }
 
