@@ -62,15 +62,15 @@ struct _ValaStructPrivate {
 #define VALA_STRUCT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STRUCT, ValaStructPrivate))
 enum  {
 	VALA_STRUCT_DUMMY_PROPERTY,
-	VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD,
+	VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD
 };
 static void vala_struct_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_struct_real_get_cname (ValaDataType* base, gboolean const_type);
 static void vala_struct_set_cname (ValaStruct* self, const char* cname);
 static void vala_struct_set_const_cname (ValaStruct* self, const char* cname);
 static char* vala_struct_real_get_lower_case_cprefix (ValaDataType* base);
 static char* vala_struct_get_lower_case_csuffix (ValaStruct* self);
-static void vala_struct_set_lower_case_csuffix (ValaStruct* self, const char* csuffix);
 static char* vala_struct_real_get_lower_case_cname (ValaDataType* base, const char* infix);
 static char* vala_struct_real_get_upper_case_cname (ValaDataType* base, const char* infix);
 static gboolean vala_struct_real_is_reference_type (ValaDataType* base);
@@ -105,13 +105,16 @@ static void vala_struct_dispose (GObject * obj);
  */
 ValaStruct* vala_struct_new (const char* _name, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaStruct * self;
 	g_return_val_if_fail (_name != NULL, NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaStruct * self = g_object_newv (VALA_TYPE_STRUCT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_STRUCT, __params_it - __params, __params);
 	return self;
 }
 
@@ -196,153 +199,181 @@ GList* vala_struct_get_methods (ValaStruct* self)
 
 static void vala_struct_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	self = VALA_STRUCT (base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_struct (visitor, self);
+}
+
+
+static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
+{
+	ValaStruct * self;
+	self = VALA_STRUCT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_visitor_visit_begin_struct (visitor, self);
 	{
-		GList* __temp2 = NULL;
-		__temp2 = self->priv->type_parameters;
+		GList* __temp2;
 		GList* p_it;
+		__temp2 = NULL;
+		__temp2 = self->priv->type_parameters;
 		for (p_it = __temp2; p_it != NULL; p_it = p_it->next) {
-			ValaTypeParameter* p = p_it->data;
+			ValaTypeParameter* p;
+			p = p_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (p), visitor);
 			}
 		}
 	}
 	{
-		GList* __temp3 = NULL;
-		__temp3 = self->priv->fields;
+		GList* __temp3;
 		GList* f_it;
+		__temp3 = NULL;
+		__temp3 = self->priv->fields;
 		for (f_it = __temp3; f_it != NULL; f_it = f_it->next) {
-			ValaField* f = f_it->data;
+			ValaField* f;
+			f = f_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (f), visitor);
 			}
 		}
 	}
 	{
-		GList* __temp4 = NULL;
-		__temp4 = self->priv->constants;
+		GList* __temp4;
 		GList* c_it;
+		__temp4 = NULL;
+		__temp4 = self->priv->constants;
 		for (c_it = __temp4; c_it != NULL; c_it = c_it->next) {
-			ValaConstant* c = c_it->data;
+			ValaConstant* c;
+			c = c_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (c), visitor);
 			}
 		}
 	}
 	{
-		GList* __temp5 = NULL;
-		__temp5 = self->priv->methods;
+		GList* __temp5;
 		GList* m_it;
+		__temp5 = NULL;
+		__temp5 = self->priv->methods;
 		for (m_it = __temp5; m_it != NULL; m_it = m_it->next) {
-			ValaMethod* m = m_it->data;
+			ValaMethod* m;
+			m = m_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
 			}
 		}
 	}
-	vala_code_visitor_visit_end_struct (visitor, self);
 }
 
 
 static char* vala_struct_real_get_cname (ValaDataType* base, gboolean const_type)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	const char* __temp10;
+	self = VALA_STRUCT (base);
 	if (const_type && self->priv->const_cname != NULL) {
-		const char* __temp6 = NULL;
+		const char* __temp6;
+		__temp6 = NULL;
 		return (__temp6 = self->priv->const_cname, (__temp6 == NULL ? NULL : g_strdup (__temp6)));
 	}
 	if (self->priv->cname == NULL) {
-		char* __temp9 = NULL;
-		char* __temp8 = NULL;
+		char* __temp9;
+		char* __temp8;
+		__temp9 = NULL;
+		__temp8 = NULL;
 		self->priv->cname = (__temp9 = g_strdup_printf ("%s%s", (__temp8 = vala_namespace_get_cprefix (VALA_DATA_TYPE (self)->namespace)), vala_data_type_get_name (VALA_DATA_TYPE (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp9);
 		(__temp8 = (g_free (__temp8), NULL));
 	}
-	const char* __temp10 = NULL;
+	__temp10 = NULL;
 	return (__temp10 = self->priv->cname, (__temp10 == NULL ? NULL : g_strdup (__temp10)));
 }
 
 
 static void vala_struct_set_cname (ValaStruct* self, const char* cname)
 {
+	char* __temp12;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (cname != NULL);
-	char* __temp12 = NULL;
+	__temp12 = NULL;
 	self->priv->cname = (__temp12 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp12);
 }
 
 
 static void vala_struct_set_const_cname (ValaStruct* self, const char* cname)
 {
+	char* __temp13;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (cname != NULL);
-	char* __temp13 = NULL;
+	__temp13 = NULL;
 	self->priv->const_cname = (__temp13 = g_strdup (cname), (self->priv->const_cname = (g_free (self->priv->const_cname), NULL)), __temp13);
 }
 
 
 static char* vala_struct_real_get_lower_case_cprefix (ValaDataType* base)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	const char* __temp16;
+	self = VALA_STRUCT (base);
 	if (self->priv->lower_case_cprefix == NULL) {
-		char* __temp15 = NULL;
-		char* __temp14 = NULL;
+		char* __temp15;
+		char* __temp14;
+		__temp15 = NULL;
+		__temp14 = NULL;
 		self->priv->lower_case_cprefix = (__temp15 = g_strdup_printf ("%s_", (__temp14 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (self), NULL))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp15);
 		(__temp14 = (g_free (__temp14), NULL));
 	}
-	const char* __temp16 = NULL;
+	__temp16 = NULL;
 	return (__temp16 = self->priv->lower_case_cprefix, (__temp16 == NULL ? NULL : g_strdup (__temp16)));
 }
 
 
 static char* vala_struct_get_lower_case_csuffix (ValaStruct* self)
 {
+	const char* __temp19;
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
 	if (self->priv->lower_case_csuffix == NULL) {
-		char* __temp18 = NULL;
+		char* __temp18;
+		__temp18 = NULL;
 		self->priv->lower_case_csuffix = (__temp18 = vala_namespace_camel_case_to_lower_case (vala_data_type_get_name (VALA_DATA_TYPE (self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp18);
 	}
-	const char* __temp19 = NULL;
+	__temp19 = NULL;
 	return (__temp19 = self->priv->lower_case_csuffix, (__temp19 == NULL ? NULL : g_strdup (__temp19)));
 }
 
 
-static void vala_struct_set_lower_case_csuffix (ValaStruct* self, const char* csuffix)
-{
-	g_return_if_fail (VALA_IS_STRUCT (self));
-	g_return_if_fail (csuffix != NULL);
-	char* __temp21 = NULL;
-	self->priv->lower_case_csuffix = (__temp21 = g_strdup (csuffix), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp21);
-}
-
-
 static char* vala_struct_real_get_lower_case_cname (ValaDataType* base, const char* infix)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	char* __temp22;
+	char* __temp21;
+	char* __temp23;
+	self = VALA_STRUCT (base);
 	if (infix == NULL) {
 		infix = "";
 	}
-	char* __temp23 = NULL;
-	char* __temp22 = NULL;
-	char* __temp24 = NULL;
-	return (__temp24 = g_strdup_printf ("%s%s%s", (__temp22 = vala_namespace_get_lower_case_cprefix (VALA_DATA_TYPE (self)->namespace)), infix, (__temp23 = vala_struct_get_lower_case_csuffix (self))), (__temp23 = (g_free (__temp23), NULL)), (__temp22 = (g_free (__temp22), NULL)), __temp24);
+	__temp22 = NULL;
+	__temp21 = NULL;
+	__temp23 = NULL;
+	return (__temp23 = g_strdup_printf ("%s%s%s", (__temp21 = vala_namespace_get_lower_case_cprefix (VALA_DATA_TYPE (self)->namespace)), infix, (__temp22 = vala_struct_get_lower_case_csuffix (self))), (__temp22 = (g_free (__temp22), NULL)), (__temp21 = (g_free (__temp21), NULL)), __temp23);
 }
 
 
 static char* vala_struct_real_get_upper_case_cname (ValaDataType* base, const char* infix)
 {
-	ValaStruct * self = VALA_STRUCT (base);
-	char* __temp26 = NULL;
-	char* __temp27 = NULL;
-	return (__temp27 = g_utf8_strup ((__temp26 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (self), infix)), -1), (__temp26 = (g_free (__temp26), NULL)), __temp27);
+	ValaStruct * self;
+	char* __temp25;
+	char* __temp26;
+	self = VALA_STRUCT (base);
+	__temp25 = NULL;
+	__temp26 = NULL;
+	return (__temp26 = g_utf8_strup ((__temp25 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (self), infix)), -1), (__temp25 = (g_free (__temp25), NULL)), __temp26);
 }
 
 
 static gboolean vala_struct_real_is_reference_type (ValaDataType* base)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	self = VALA_STRUCT (base);
 	return self->priv->reference_type;
 }
 
@@ -400,59 +431,70 @@ static void vala_struct_process_ccode_attribute (ValaStruct* self, ValaAttribute
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
-		char* __temp33 = NULL;
-		vala_struct_set_cname (self, (__temp33 = vala_attribute_get_string (a, "cname")));
-		(__temp33 = (g_free (__temp33), NULL));
+		char* __temp32;
+		__temp32 = NULL;
+		vala_struct_set_cname (self, (__temp32 = vala_attribute_get_string (a, "cname")));
+		(__temp32 = (g_free (__temp32), NULL));
 	}
 	if (vala_attribute_has_argument (a, "const_cname")) {
-		char* __temp34 = NULL;
-		vala_struct_set_const_cname (self, (__temp34 = vala_attribute_get_string (a, "const_cname")));
-		(__temp34 = (g_free (__temp34), NULL));
+		char* __temp33;
+		__temp33 = NULL;
+		vala_struct_set_const_cname (self, (__temp33 = vala_attribute_get_string (a, "const_cname")));
+		(__temp33 = (g_free (__temp33), NULL));
 	}
 	if (vala_attribute_has_argument (a, "cprefix")) {
-		char* __temp35 = NULL;
-		self->priv->lower_case_cprefix = (__temp35 = vala_attribute_get_string (a, "cprefix"), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp35);
+		char* __temp34;
+		__temp34 = NULL;
+		self->priv->lower_case_cprefix = (__temp34 = vala_attribute_get_string (a, "cprefix"), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp34);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
-		char* val = vala_attribute_get_string (a, "cheader_filename");
+		char* val;
+		val = vala_attribute_get_string (a, "cheader_filename");
 		{
-			char** __temp36 = NULL;
-			__temp36 = g_strsplit (val, ",", 0);
+			char** __temp35;
 			char** filename_it;
-			for (filename_it = __temp36; *filename_it != NULL; filename_it = filename_it + 1) {
-				char* filename = *filename_it;
+			__temp35 = NULL;
+			__temp35 = g_strsplit (val, ",", 0);
+			for (filename_it = __temp35; *filename_it != NULL; filename_it = filename_it + 1) {
+				char* filename;
+				filename = *filename_it;
 				{
 					vala_data_type_add_cheader_filename (VALA_DATA_TYPE (self), filename);
 				}
 			}
-			(__temp36 = (g_free (__temp36), NULL));
+			(__temp35 = (g_free (__temp35), NULL));
 		}
 		(val = (g_free (val), NULL));
 	}
 	if (vala_attribute_has_argument (a, "type_id")) {
-		char* __temp37 = NULL;
-		vala_struct_set_type_id (self, (__temp37 = vala_attribute_get_string (a, "type_id")));
-		(__temp37 = (g_free (__temp37), NULL));
+		char* __temp36;
+		__temp36 = NULL;
+		vala_struct_set_type_id (self, (__temp36 = vala_attribute_get_string (a, "type_id")));
+		(__temp36 = (g_free (__temp36), NULL));
 	}
 	if (vala_attribute_has_argument (a, "marshaller_type_name")) {
-		char* __temp38 = NULL;
-		vala_struct_set_marshaller_type_name (self, (__temp38 = vala_attribute_get_string (a, "marshaller_type_name")));
-		(__temp38 = (g_free (__temp38), NULL));
+		char* __temp37;
+		__temp37 = NULL;
+		vala_struct_set_marshaller_type_name (self, (__temp37 = vala_attribute_get_string (a, "marshaller_type_name")));
+		(__temp37 = (g_free (__temp37), NULL));
 	}
 	if (vala_attribute_has_argument (a, "get_value_function")) {
-		char* __temp39 = NULL;
-		vala_struct_set_get_value_function (self, (__temp39 = vala_attribute_get_string (a, "get_value_function")));
-		(__temp39 = (g_free (__temp39), NULL));
+		char* __temp38;
+		__temp38 = NULL;
+		vala_struct_set_get_value_function (self, (__temp38 = vala_attribute_get_string (a, "get_value_function")));
+		(__temp38 = (g_free (__temp38), NULL));
 	}
 	if (vala_attribute_has_argument (a, "set_value_function")) {
-		char* __temp40 = NULL;
-		vala_struct_set_set_value_function (self, (__temp40 = vala_attribute_get_string (a, "set_value_function")));
-		(__temp40 = (g_free (__temp40), NULL));
+		char* __temp39;
+		__temp39 = NULL;
+		vala_struct_set_set_value_function (self, (__temp39 = vala_attribute_get_string (a, "set_value_function")));
+		(__temp39 = (g_free (__temp39), NULL));
 	}
 	if (vala_attribute_has_argument (a, "default_value")) {
-		char* __temp41 = NULL;
-		vala_struct_set_default_value (self, (__temp41 = vala_attribute_get_string (a, "default_value")));
-		(__temp41 = (g_free (__temp41), NULL));
+		char* __temp40;
+		__temp40 = NULL;
+		vala_struct_set_default_value (self, (__temp40 = vala_attribute_get_string (a, "default_value")));
+		(__temp40 = (g_free (__temp40), NULL));
 	}
 }
 
@@ -463,14 +505,16 @@ static void vala_struct_process_ref_type_attribute (ValaStruct* self, ValaAttrib
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	self->priv->reference_type = TRUE;
 	if (vala_attribute_has_argument (a, "dup_function")) {
-		char* __temp42 = NULL;
-		vala_struct_set_dup_function (self, (__temp42 = vala_attribute_get_string (a, "dup_function")));
-		(__temp42 = (g_free (__temp42), NULL));
+		char* __temp41;
+		__temp41 = NULL;
+		vala_struct_set_dup_function (self, (__temp41 = vala_attribute_get_string (a, "dup_function")));
+		(__temp41 = (g_free (__temp41), NULL));
 	}
 	if (vala_attribute_has_argument (a, "free_function")) {
-		char* __temp43 = NULL;
-		vala_struct_set_free_function (self, (__temp43 = vala_attribute_get_string (a, "free_function")));
-		(__temp43 = (g_free (__temp43), NULL));
+		char* __temp42;
+		__temp42 = NULL;
+		vala_struct_set_free_function (self, (__temp42 = vala_attribute_get_string (a, "free_function")));
+		(__temp42 = (g_free (__temp42), NULL));
 	}
 }
 
@@ -504,11 +548,13 @@ void vala_struct_process_attributes (ValaStruct* self)
 {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	{
-		GList* __temp44 = NULL;
-		__temp44 = VALA_CODE_NODE (self)->attributes;
+		GList* __temp43;
 		GList* a_it;
-		for (a_it = __temp44; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* a = a_it->data;
+		__temp43 = NULL;
+		__temp43 = VALA_CODE_NODE (self)->attributes;
+		for (a_it = __temp43; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* a;
+			a = a_it->data;
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_struct_process_ccode_attribute (self, a);
@@ -533,132 +579,160 @@ void vala_struct_process_attributes (ValaStruct* self)
 
 static gboolean vala_struct_real_is_reference_counting (ValaDataType* base)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	self = VALA_STRUCT (base);
 	return FALSE;
 }
 
 
 static char* vala_struct_real_get_dup_function (ValaDataType* base)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	const char* __temp47;
+	self = VALA_STRUCT (base);
 	if (self->priv->dup_function == NULL) {
-		char* __temp47 = NULL;
-		char* __temp46 = NULL;
-		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp47 = g_strdup_printf ("The type `%s` doesn't contain a copy function", (__temp46 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
-		(__temp47 = (g_free (__temp47), NULL));
+		char* __temp46;
+		char* __temp45;
+		__temp46 = NULL;
+		__temp45 = NULL;
+		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp46 = g_strdup_printf ("The type `%s` doesn't contain a copy function", (__temp45 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
 		(__temp46 = (g_free (__temp46), NULL));
+		(__temp45 = (g_free (__temp45), NULL));
 	}
-	const char* __temp48 = NULL;
-	return (__temp48 = self->priv->dup_function, (__temp48 == NULL ? NULL : g_strdup (__temp48)));
+	__temp47 = NULL;
+	return (__temp47 = self->priv->dup_function, (__temp47 == NULL ? NULL : g_strdup (__temp47)));
 }
 
 
 void vala_struct_set_dup_function (ValaStruct* self, const char* name)
 {
+	char* __temp49;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (name != NULL);
-	char* __temp50 = NULL;
-	self->priv->dup_function = (__temp50 = g_strdup (name), (self->priv->dup_function = (g_free (self->priv->dup_function), NULL)), __temp50);
+	__temp49 = NULL;
+	self->priv->dup_function = (__temp49 = g_strdup (name), (self->priv->dup_function = (g_free (self->priv->dup_function), NULL)), __temp49);
 }
 
 
 static char* vala_struct_real_get_free_function (ValaDataType* base)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	const char* __temp52;
+	self = VALA_STRUCT (base);
 	if (self->priv->free_function == NULL) {
-		char* __temp52 = NULL;
-		char* __temp51 = NULL;
-		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp52 = g_strdup_printf ("The type `%s` doesn't contain a free function", (__temp51 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
-		(__temp52 = (g_free (__temp52), NULL));
+		char* __temp51;
+		char* __temp50;
+		__temp51 = NULL;
+		__temp50 = NULL;
+		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp51 = g_strdup_printf ("The type `%s` doesn't contain a free function", (__temp50 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
 		(__temp51 = (g_free (__temp51), NULL));
+		(__temp50 = (g_free (__temp50), NULL));
 	}
-	const char* __temp53 = NULL;
-	return (__temp53 = self->priv->free_function, (__temp53 == NULL ? NULL : g_strdup (__temp53)));
+	__temp52 = NULL;
+	return (__temp52 = self->priv->free_function, (__temp52 == NULL ? NULL : g_strdup (__temp52)));
 }
 
 
 static void vala_struct_set_free_function (ValaStruct* self, const char* name)
 {
+	char* __temp54;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (name != NULL);
-	char* __temp55 = NULL;
-	self->priv->free_function = (__temp55 = g_strdup (name), (self->priv->free_function = (g_free (self->priv->free_function), NULL)), __temp55);
+	__temp54 = NULL;
+	self->priv->free_function = (__temp54 = g_strdup (name), (self->priv->free_function = (g_free (self->priv->free_function), NULL)), __temp54);
 }
 
 
 static char* vala_struct_real_get_type_id (ValaDataType* base)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	const char* __temp58;
+	self = VALA_STRUCT (base);
 	if (self->priv->type_id == NULL) {
 		if (vala_data_type_is_reference_type (VALA_DATA_TYPE (self))) {
-			char* __temp56 = NULL;
-			self->priv->type_id = (__temp56 = g_strdup ("G_TYPE_POINTER"), (self->priv->type_id = (g_free (self->priv->type_id), NULL)), __temp56);
+			char* __temp55;
+			__temp55 = NULL;
+			self->priv->type_id = (__temp55 = g_strdup ("G_TYPE_POINTER"), (self->priv->type_id = (g_free (self->priv->type_id), NULL)), __temp55);
 		} else {
-			char* __temp58 = NULL;
-			char* __temp57 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp58 = g_strdup_printf ("The type `%s` doesn't declare a type id", (__temp57 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
-			(__temp58 = (g_free (__temp58), NULL));
+			char* __temp57;
+			char* __temp56;
+			__temp57 = NULL;
+			__temp56 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp57 = g_strdup_printf ("The type `%s` doesn't declare a type id", (__temp56 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
 			(__temp57 = (g_free (__temp57), NULL));
+			(__temp56 = (g_free (__temp56), NULL));
 		}
 	}
-	const char* __temp59 = NULL;
-	return (__temp59 = self->priv->type_id, (__temp59 == NULL ? NULL : g_strdup (__temp59)));
+	__temp58 = NULL;
+	return (__temp58 = self->priv->type_id, (__temp58 == NULL ? NULL : g_strdup (__temp58)));
 }
 
 
 void vala_struct_set_type_id (ValaStruct* self, const char* name)
 {
+	char* __temp60;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (name != NULL);
-	char* __temp61 = NULL;
-	self->priv->type_id = (__temp61 = g_strdup (name), (self->priv->type_id = (g_free (self->priv->type_id), NULL)), __temp61);
+	__temp60 = NULL;
+	self->priv->type_id = (__temp60 = g_strdup (name), (self->priv->type_id = (g_free (self->priv->type_id), NULL)), __temp60);
 }
 
 
 static char* vala_struct_real_get_marshaller_type_name (ValaDataType* base)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	const char* __temp64;
+	self = VALA_STRUCT (base);
 	if (self->priv->marshaller_type_name == NULL) {
 		if (vala_data_type_is_reference_type (VALA_DATA_TYPE (self))) {
-			char* __temp62 = NULL;
-			self->priv->marshaller_type_name = (__temp62 = g_strdup ("POINTER"), (self->priv->marshaller_type_name = (g_free (self->priv->marshaller_type_name), NULL)), __temp62);
+			char* __temp61;
+			__temp61 = NULL;
+			self->priv->marshaller_type_name = (__temp61 = g_strdup ("POINTER"), (self->priv->marshaller_type_name = (g_free (self->priv->marshaller_type_name), NULL)), __temp61);
 		} else {
-			char* __temp64 = NULL;
-			char* __temp63 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp64 = g_strdup_printf ("The type `%s` doesn't declare a marshaller type name", (__temp63 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
-			(__temp64 = (g_free (__temp64), NULL));
+			char* __temp63;
+			char* __temp62;
+			__temp63 = NULL;
+			__temp62 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp63 = g_strdup_printf ("The type `%s` doesn't declare a marshaller type name", (__temp62 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
 			(__temp63 = (g_free (__temp63), NULL));
+			(__temp62 = (g_free (__temp62), NULL));
 		}
 	}
-	const char* __temp65 = NULL;
-	return (__temp65 = self->priv->marshaller_type_name, (__temp65 == NULL ? NULL : g_strdup (__temp65)));
+	__temp64 = NULL;
+	return (__temp64 = self->priv->marshaller_type_name, (__temp64 == NULL ? NULL : g_strdup (__temp64)));
 }
 
 
 static void vala_struct_set_marshaller_type_name (ValaStruct* self, const char* name)
 {
+	char* __temp66;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (name != NULL);
-	char* __temp67 = NULL;
-	self->priv->marshaller_type_name = (__temp67 = g_strdup (name), (self->priv->marshaller_type_name = (g_free (self->priv->marshaller_type_name), NULL)), __temp67);
+	__temp66 = NULL;
+	self->priv->marshaller_type_name = (__temp66 = g_strdup (name), (self->priv->marshaller_type_name = (g_free (self->priv->marshaller_type_name), NULL)), __temp66);
 }
 
 
 static char* vala_struct_real_get_get_value_function (ValaDataType* base)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	self = VALA_STRUCT (base);
 	if (self->priv->get_value_function == NULL) {
 		if (vala_data_type_is_reference_type (VALA_DATA_TYPE (self))) {
 			return g_strdup ("g_value_get_pointer");
 		} else {
-			char* __temp70 = NULL;
-			char* __temp69 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp70 = g_strdup_printf ("The value type `%s` doesn't declare a GValue get function", (__temp69 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
-			(__temp70 = (g_free (__temp70), NULL));
+			char* __temp69;
+			char* __temp68;
+			__temp69 = NULL;
+			__temp68 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp69 = g_strdup_printf ("The value type `%s` doesn't declare a GValue get function", (__temp68 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
 			(__temp69 = (g_free (__temp69), NULL));
+			(__temp68 = (g_free (__temp68), NULL));
+			return NULL;
 		}
 	} else {
-		const char* __temp71 = NULL;
+		const char* __temp71;
+		__temp71 = NULL;
 		return (__temp71 = self->priv->get_value_function, (__temp71 == NULL ? NULL : g_strdup (__temp71)));
 	}
 }
@@ -666,56 +740,66 @@ static char* vala_struct_real_get_get_value_function (ValaDataType* base)
 
 static char* vala_struct_real_get_set_value_function (ValaDataType* base)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	self = VALA_STRUCT (base);
 	if (self->priv->set_value_function == NULL) {
 		if (vala_data_type_is_reference_type (VALA_DATA_TYPE (self))) {
 			return g_strdup ("g_value_set_pointer");
 		} else {
-			char* __temp75 = NULL;
-			char* __temp74 = NULL;
+			char* __temp75;
+			char* __temp74;
+			__temp75 = NULL;
+			__temp74 = NULL;
 			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp75 = g_strdup_printf ("The value type `%s` doesn't declare a GValue set function", (__temp74 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
 			(__temp75 = (g_free (__temp75), NULL));
 			(__temp74 = (g_free (__temp74), NULL));
+			return NULL;
 		}
 	} else {
-		const char* __temp76 = NULL;
-		return (__temp76 = self->priv->set_value_function, (__temp76 == NULL ? NULL : g_strdup (__temp76)));
+		const char* __temp77;
+		__temp77 = NULL;
+		return (__temp77 = self->priv->set_value_function, (__temp77 == NULL ? NULL : g_strdup (__temp77)));
 	}
 }
 
 
 static void vala_struct_set_get_value_function (ValaStruct* self, const char* function)
 {
+	char* __temp79;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (function != NULL);
-	char* __temp78 = NULL;
-	self->priv->get_value_function = (__temp78 = g_strdup (function), (self->priv->get_value_function = (g_free (self->priv->get_value_function), NULL)), __temp78);
+	__temp79 = NULL;
+	self->priv->get_value_function = (__temp79 = g_strdup (function), (self->priv->get_value_function = (g_free (self->priv->get_value_function), NULL)), __temp79);
 }
 
 
 static void vala_struct_set_set_value_function (ValaStruct* self, const char* function)
 {
+	char* __temp80;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (function != NULL);
-	char* __temp79 = NULL;
-	self->priv->set_value_function = (__temp79 = g_strdup (function), (self->priv->set_value_function = (g_free (self->priv->set_value_function), NULL)), __temp79);
+	__temp80 = NULL;
+	self->priv->set_value_function = (__temp80 = g_strdup (function), (self->priv->set_value_function = (g_free (self->priv->set_value_function), NULL)), __temp80);
 }
 
 
 static char* vala_struct_real_get_default_value (ValaDataType* base)
 {
-	ValaStruct * self = VALA_STRUCT (base);
-	const char* __temp80 = NULL;
-	return (__temp80 = self->priv->default_value, (__temp80 == NULL ? NULL : g_strdup (__temp80)));
+	ValaStruct * self;
+	const char* __temp81;
+	self = VALA_STRUCT (base);
+	__temp81 = NULL;
+	return (__temp81 = self->priv->default_value, (__temp81 == NULL ? NULL : g_strdup (__temp81)));
 }
 
 
 static void vala_struct_set_default_value (ValaStruct* self, const char* value)
 {
+	char* __temp83;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (value != NULL);
-	char* __temp82 = NULL;
-	self->priv->default_value = (__temp82 = g_strdup (value), (self->priv->default_value = (g_free (self->priv->default_value), NULL)), __temp82);
+	__temp83 = NULL;
+	self->priv->default_value = (__temp83 = g_strdup (value), (self->priv->default_value = (g_free (self->priv->default_value), NULL)), __temp83);
 }
 
 
@@ -746,15 +830,19 @@ GList* vala_struct_get_base_types (ValaStruct* self)
 
 static gint vala_struct_real_get_type_parameter_index (ValaDataType* base, const char* name)
 {
-	ValaStruct * self = VALA_STRUCT (base);
+	ValaStruct * self;
+	gint i;
+	self = VALA_STRUCT (base);
 	g_return_val_if_fail (name != NULL, 0);
-	gint i = 0;
+	i = 0;
 	{
-		GList* __temp85 = NULL;
-		__temp85 = self->priv->type_parameters;
+		GList* __temp86;
 		GList* p_it;
-		for (p_it = __temp85; p_it != NULL; p_it = p_it->next) {
-			ValaTypeParameter* p = p_it->data;
+		__temp86 = NULL;
+		__temp86 = self->priv->type_parameters;
+		for (p_it = __temp86; p_it != NULL; p_it = p_it->next) {
+			ValaTypeParameter* p;
+			p = p_it->data;
 			{
 				if (g_utf8_collate (vala_type_parameter_get_name (p), name) == 0) {
 					return (i);
@@ -776,16 +864,19 @@ ValaMethod* vala_struct_get_default_construction_method (ValaStruct* self)
 
 void vala_struct_set_default_construction_method (ValaStruct* self, ValaMethod* value)
 {
+	ValaMethod* __temp90;
+	ValaMethod* __temp89;
 	g_return_if_fail (VALA_IS_STRUCT (self));
-	ValaMethod* __temp89 = NULL;
-	ValaMethod* __temp88 = NULL;
-	self->priv->_default_construction_method = (__temp89 = (__temp88 = value, (__temp88 == NULL ? NULL : g_object_ref (__temp88))), (self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL))), __temp89);
+	__temp90 = NULL;
+	__temp89 = NULL;
+	self->priv->_default_construction_method = (__temp90 = (__temp89 = value, (__temp89 == NULL ? NULL : g_object_ref (__temp89))), (self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL))), __temp90);
 }
 
 
 static void vala_struct_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaStruct * self = VALA_STRUCT (object);
+	ValaStruct * self;
+	self = VALA_STRUCT (object);
 	switch (property_id) {
 		case VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD:
 		g_value_set_object (value, vala_struct_get_default_construction_method (self));
@@ -796,7 +887,8 @@ static void vala_struct_get_property (GObject * object, guint property_id, GValu
 
 static void vala_struct_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaStruct * self = VALA_STRUCT (object);
+	ValaStruct * self;
+	self = VALA_STRUCT (object);
 	switch (property_id) {
 		case VALA_STRUCT_DEFAULT_CONSTRUCTION_METHOD:
 		vala_struct_set_default_construction_method (self, g_value_get_object (value));
@@ -813,6 +905,7 @@ static void vala_struct_class_init (ValaStructClass * klass)
 	G_OBJECT_CLASS (klass)->set_property = vala_struct_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_struct_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_struct_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_struct_real_accept_children;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_struct_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cprefix = vala_struct_real_get_lower_case_cprefix;
 	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cname = vala_struct_real_get_lower_case_cname;
@@ -840,7 +933,10 @@ static void vala_struct_init (ValaStruct * self)
 
 static void vala_struct_dispose (GObject * obj)
 {
-	ValaStruct * self = VALA_STRUCT (obj);
+	ValaStruct * self;
+	ValaStructClass * klass;
+	GObjectClass * parent_class;
+	self = VALA_STRUCT (obj);
 	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_list_foreach (self->priv->type_parameters, (GFunc) g_object_unref, NULL), g_list_free (self->priv->type_parameters), NULL)));
 	(self->priv->constants == NULL ? NULL : (self->priv->constants = (g_list_foreach (self->priv->constants, (GFunc) g_object_unref, NULL), g_list_free (self->priv->constants), NULL)));
 	(self->priv->fields == NULL ? NULL : (self->priv->fields = (g_list_foreach (self->priv->fields, (GFunc) g_object_unref, NULL), g_list_free (self->priv->fields), NULL)));
@@ -858,8 +954,6 @@ static void vala_struct_dispose (GObject * obj)
 	(self->priv->set_value_function = (g_free (self->priv->set_value_function), NULL));
 	(self->priv->default_value = (g_free (self->priv->default_value), NULL));
 	(self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL)));
-	ValaStructClass * klass;
-	GObjectClass * parent_class;
 	klass = VALA_STRUCT_CLASS (g_type_class_peek (VALA_TYPE_STRUCT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
