@@ -40,7 +40,6 @@
 #include <vala/valasymbol.h>
 
 struct _ValaTypeReferencePrivate {
-	gboolean _reference_to_value_type;
 	gboolean _transfers_ownership;
 	gboolean _takes_ownership;
 	gboolean _is_out;
@@ -60,7 +59,6 @@ struct _ValaTypeReferencePrivate {
 #define VALA_TYPE_REFERENCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TYPE_REFERENCE, ValaTypeReferencePrivate))
 enum  {
 	VALA_TYPE_REFERENCE_DUMMY_PROPERTY,
-	VALA_TYPE_REFERENCE_REFERENCE_TO_VALUE_TYPE,
 	VALA_TYPE_REFERENCE_TRANSFERS_OWNERSHIP,
 	VALA_TYPE_REFERENCE_TAKES_OWNERSHIP,
 	VALA_TYPE_REFERENCE_IS_OUT,
@@ -74,7 +72,7 @@ enum  {
 	VALA_TYPE_REFERENCE_ARRAY_RANK,
 	VALA_TYPE_REFERENCE_POINTER_LEVEL,
 	VALA_TYPE_REFERENCE_IS_REF,
-	VALA_TYPE_REFERENCE_IS_WEAK,
+	VALA_TYPE_REFERENCE_IS_WEAK
 };
 static void vala_type_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_type_reference_parent_class = NULL;
@@ -83,9 +81,12 @@ static void vala_type_reference_dispose (GObject * obj);
 
 ValaTypeReference* vala_type_reference_new ()
 {
-	GParameter * __params = g_new0 (GParameter, 0);
-	GParameter * __params_it = __params;
-	ValaTypeReference * self = g_object_newv (VALA_TYPE_TYPE_REFERENCE, __params_it - __params, __params);
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaTypeReference * self;
+	__params = g_new0 (GParameter, 0);
+	__params_it = __params;
+	self = g_object_newv (VALA_TYPE_TYPE_REFERENCE, __params_it - __params, __params);
 	return self;
 }
 
@@ -100,14 +101,17 @@ ValaTypeReference* vala_type_reference_new ()
  */
 ValaTypeReference* vala_type_reference_new_from_name (const char* ns, const char* type, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaTypeReference * self;
 	g_return_val_if_fail (type != NULL, NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 3);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
 	(__params_it->name = "namespace-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, ns), __params_it++);
 	(__params_it->name = "type-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, type), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaTypeReference * self = g_object_newv (VALA_TYPE_TYPE_REFERENCE, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_TYPE_REFERENCE, __params_it - __params, __params);
 	return self;
 }
 
@@ -121,39 +125,53 @@ ValaTypeReference* vala_type_reference_new_from_name (const char* ns, const char
  */
 ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr)
 {
+	char* ns;
+	char* type_name;
+	gpointer __temp6;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (expr), NULL);
-	char* ns = NULL;
-	char* type_name = NULL;
+	ns = NULL;
+	type_name = NULL;
 	if (VALA_IS_MEMBER_ACCESS (expr)) {
-		ValaTypeReference* type_ref = NULL;
-		ValaMemberAccess* __temp0 = NULL;
-		ValaMemberAccess* ma = (__temp0 = VALA_MEMBER_ACCESS (expr), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
+		ValaTypeReference* type_ref;
+		ValaMemberAccess* __temp0;
+		ValaMemberAccess* ma;
+		type_ref = NULL;
+		__temp0 = NULL;
+		ma = (__temp0 = VALA_MEMBER_ACCESS (expr), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
 		if (vala_member_access_get_inner (ma) != NULL) {
 			if (VALA_IS_MEMBER_ACCESS (vala_member_access_get_inner (ma))) {
-				ValaMemberAccess* __temp1 = NULL;
-				ValaMemberAccess* simple = (__temp1 = VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
-				ValaTypeReference* __temp2 = NULL;
+				ValaMemberAccess* __temp1;
+				ValaMemberAccess* simple;
+				ValaTypeReference* __temp2;
+				__temp1 = NULL;
+				simple = (__temp1 = VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
+				__temp2 = NULL;
 				type_ref = (__temp2 = vala_type_reference_new_from_name (vala_member_access_get_member_name (simple), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), __temp2);
 				(simple == NULL ? NULL : (simple = (g_object_unref (simple), NULL)));
 			}
 		} else {
-			ValaTypeReference* __temp3 = NULL;
+			ValaTypeReference* __temp3;
+			__temp3 = NULL;
 			type_ref = (__temp3 = vala_type_reference_new_from_name (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), __temp3);
 		}
 		if (type_ref != NULL) {
-			GList* type_args = vala_member_access_get_type_arguments (ma);
+			GList* type_args;
+			ValaTypeReference* __temp5;
+			type_args = vala_member_access_get_type_arguments (ma);
 			{
-				GList* __temp4 = NULL;
-				__temp4 = type_args;
+				GList* __temp4;
 				GList* arg_it;
+				__temp4 = NULL;
+				__temp4 = type_args;
 				for (arg_it = __temp4; arg_it != NULL; arg_it = arg_it->next) {
-					ValaTypeReference* arg = arg_it->data;
+					ValaTypeReference* arg;
+					arg = arg_it->data;
 					{
 						vala_type_reference_add_type_argument (type_ref, arg);
 					}
 				}
 			}
-			ValaTypeReference* __temp5 = NULL;
+			__temp5 = NULL;
 			return (__temp5 = type_ref, (type_args == NULL ? NULL : (type_args = (g_list_free (type_args), NULL))), __temp5);
 			(type_args == NULL ? NULL : (type_args = (g_list_free (type_args), NULL)));
 		}
@@ -161,7 +179,6 @@ ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr
 		(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
 	}
 	vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (expr)), "Type reference must be simple name or member access expression");
-	gpointer __temp6;
 	return VALA_TYPE_REFERENCE ((__temp6 = NULL, (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), __temp6));
 	(ns = (g_free (ns), NULL));
 	(type_name = (g_free (type_name), NULL));
@@ -198,22 +215,26 @@ GList* vala_type_reference_get_type_arguments (ValaTypeReference* self)
  */
 void vala_type_reference_remove_all_type_arguments (ValaTypeReference* self)
 {
+	GList* __temp8;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	GList* __temp8 = NULL;
+	__temp8 = NULL;
 	self->priv->type_argument_list = (__temp8 = NULL, (self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_list_foreach (self->priv->type_argument_list, (GFunc) g_object_unref, NULL), g_list_free (self->priv->type_argument_list), NULL))), __temp8);
 }
 
 
 static void vala_type_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaTypeReference * self = VALA_TYPE_REFERENCE (base);
+	ValaTypeReference * self;
+	self = VALA_TYPE_REFERENCE (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
-		GList* __temp9 = NULL;
-		__temp9 = self->priv->type_argument_list;
+		GList* __temp9;
 		GList* type_arg_it;
+		__temp9 = NULL;
+		__temp9 = self->priv->type_argument_list;
 		for (type_arg_it = __temp9; type_arg_it != NULL; type_arg_it = type_arg_it->next) {
-			ValaTypeReference* type_arg = type_arg_it->data;
+			ValaTypeReference* type_arg;
+			type_arg = type_arg_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (type_arg), visitor);
 			}
@@ -230,6 +251,8 @@ static void vala_type_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor
  */
 char* vala_type_reference_get_cname (ValaTypeReference* self, gboolean var_type, gboolean const_type)
 {
+	char* ptr;
+	char* arr;
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	if (vala_type_reference_get_data_type (self) == NULL && vala_type_reference_get_type_parameter (self) == NULL) {
 		if (var_type) {
@@ -238,33 +261,40 @@ char* vala_type_reference_get_cname (ValaTypeReference* self, gboolean var_type,
 			return g_strdup ("void");
 		}
 	}
-	char* ptr = NULL;
-	char* arr = NULL;
-	if (vala_type_reference_get_type_parameter (self) != NULL || (!vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && !vala_type_reference_get_reference_to_value_type (self))) {
-		char* __temp12 = NULL;
+	ptr = NULL;
+	arr = NULL;
+	if (vala_type_reference_get_type_parameter (self) != NULL || (!vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && !vala_type_reference_get_is_ref (self) && !vala_type_reference_get_is_out (self))) {
+		char* __temp12;
+		__temp12 = NULL;
 		ptr = (__temp12 = g_strdup (""), (ptr = (g_free (ptr), NULL)), __temp12);
 	} else {
-		if ((vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && !vala_type_reference_get_is_out (self)) || vala_type_reference_get_reference_to_value_type (self)) {
-			char* __temp13 = NULL;
+		if ((vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && !vala_type_reference_get_is_ref (self) && !vala_type_reference_get_is_out (self)) || (!vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && (vala_type_reference_get_is_ref (self) || vala_type_reference_get_is_out (self)))) {
+			char* __temp13;
+			__temp13 = NULL;
 			ptr = (__temp13 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), __temp13);
 		} else {
-			char* __temp14 = NULL;
+			char* __temp14;
+			__temp14 = NULL;
 			ptr = (__temp14 = g_strdup ("**"), (ptr = (g_free (ptr), NULL)), __temp14);
 		}
 	}
 	if (vala_type_reference_get_data_type (self) != NULL) {
-		char* __temp15 = NULL;
-		char* __temp16 = NULL;
-		char* __temp17 = NULL;
+		char* __temp15;
+		char* __temp16;
+		char* __temp17;
+		__temp15 = NULL;
+		__temp16 = NULL;
+		__temp17 = NULL;
 		return (__temp17 = (__temp16 = g_strconcat ((__temp15 = vala_data_type_get_cname (vala_type_reference_get_data_type (self), const_type)), ptr, arr, NULL, NULL), (__temp15 = (g_free (__temp15), NULL)), __temp16), (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp17);
 	} else {
 		if (vala_type_reference_get_type_parameter (self) != NULL) {
-			char* __temp18 = NULL;
+			char* __temp18;
+			__temp18 = NULL;
 			return (__temp18 = g_strconcat ("gpointer", ptr, arr, NULL, NULL), (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp18);
 		} else {
+			gpointer __temp19;
 			/* raise error */
 			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), "unresolved type reference");
-			gpointer __temp19;
 			return (__temp19 = NULL, (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp19);
 		}
 	}
@@ -281,29 +311,40 @@ char* vala_type_reference_get_cname (ValaTypeReference* self, gboolean var_type,
  */
 char* vala_type_reference_get_const_cname (ValaTypeReference* self)
 {
+	char* ptr;
+	ValaDataType* t;
+	char* __temp26;
+	char* __temp27;
+	char* __temp28;
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
-	char* ptr = NULL;
-	ValaDataType* t = NULL;
+	ptr = NULL;
+	t = NULL;
 	/* FIXME: dirty hack to make constant arrays possible */
 	if (VALA_IS_ARRAY (vala_type_reference_get_data_type (self))) {
-		ValaDataType* __temp21 = NULL;
-		ValaDataType* __temp20 = NULL;
+		ValaDataType* __temp21;
+		ValaDataType* __temp20;
+		__temp21 = NULL;
+		__temp20 = NULL;
 		t = (__temp21 = (__temp20 = vala_array_get_element_type ((VALA_ARRAY (vala_type_reference_get_data_type (self)))), (__temp20 == NULL ? NULL : g_object_ref (__temp20))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp21);
 	} else {
-		ValaDataType* __temp23 = NULL;
-		ValaDataType* __temp22 = NULL;
+		ValaDataType* __temp23;
+		ValaDataType* __temp22;
+		__temp23 = NULL;
+		__temp22 = NULL;
 		t = (__temp23 = (__temp22 = vala_type_reference_get_data_type (self), (__temp22 == NULL ? NULL : g_object_ref (__temp22))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp23);
 	}
 	if (!vala_data_type_is_reference_type (t)) {
-		char* __temp24 = NULL;
+		char* __temp24;
+		__temp24 = NULL;
 		ptr = (__temp24 = g_strdup (""), (ptr = (g_free (ptr), NULL)), __temp24);
 	} else {
-		char* __temp25 = NULL;
+		char* __temp25;
+		__temp25 = NULL;
 		ptr = (__temp25 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), __temp25);
 	}
-	char* __temp26 = NULL;
-	char* __temp27 = NULL;
-	char* __temp28 = NULL;
+	__temp26 = NULL;
+	__temp27 = NULL;
+	__temp28 = NULL;
 	return (__temp28 = (__temp27 = g_strdup_printf ("const %s%s", (__temp26 = vala_data_type_get_cname (t, FALSE)), ptr), (__temp26 = (g_free (__temp26), NULL)), __temp27), (ptr = (g_free (ptr), NULL)), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp28);
 	(ptr = (g_free (ptr), NULL));
 	(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
@@ -338,10 +379,10 @@ char* vala_type_reference_to_string (ValaTypeReference* self)
  */
 ValaTypeReference* vala_type_reference_copy (ValaTypeReference* self)
 {
+	ValaTypeReference* result;
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
-	ValaTypeReference* result = vala_type_reference_new ();
+	result = vala_type_reference_new ();
 	(vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self))), vala_code_node_get_source_reference (VALA_CODE_NODE (result)));
-	(vala_type_reference_set_reference_to_value_type (result, vala_type_reference_get_reference_to_value_type (self)), vala_type_reference_get_reference_to_value_type (result));
 	(vala_type_reference_set_transfers_ownership (result, vala_type_reference_get_transfers_ownership (self)), vala_type_reference_get_transfers_ownership (result));
 	(vala_type_reference_set_takes_ownership (result, vala_type_reference_get_takes_ownership (self)), vala_type_reference_get_takes_ownership (result));
 	(vala_type_reference_set_is_out (result, vala_type_reference_get_is_out (self)), vala_type_reference_get_is_out (result));
@@ -356,11 +397,13 @@ ValaTypeReference* vala_type_reference_copy (ValaTypeReference* self)
 	(vala_type_reference_set_is_ref (result, vala_type_reference_get_is_ref (self)), vala_type_reference_get_is_ref (result));
 	(vala_type_reference_set_is_weak (result, vala_type_reference_get_is_weak (self)), vala_type_reference_get_is_weak (result));
 	{
-		GList* __temp32 = NULL;
-		__temp32 = self->priv->type_argument_list;
+		GList* __temp32;
 		GList* arg_it;
+		__temp32 = NULL;
+		__temp32 = self->priv->type_argument_list;
 		for (arg_it = __temp32; arg_it != NULL; arg_it = arg_it->next) {
-			ValaTypeReference* arg = arg_it->data;
+			ValaTypeReference* arg;
+			arg = arg_it->data;
 			{
 				result->priv->type_argument_list = g_list_append (result->priv->type_argument_list, vala_type_reference_copy (arg));
 			}
@@ -383,15 +426,15 @@ gboolean vala_type_reference_equals (ValaTypeReference* self, ValaTypeReference*
 {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type2), FALSE);
-	if (vala_type_reference_get_reference_to_value_type (type2) != vala_type_reference_get_reference_to_value_type (self)) {
-		return FALSE;
-	}
 	if (vala_type_reference_get_transfers_ownership (type2) != vala_type_reference_get_transfers_ownership (self)) {
 		return FALSE;
 	}
 	if (vala_type_reference_get_takes_ownership (type2) != vala_type_reference_get_takes_ownership (self)) {
 		return FALSE;
 	}
+	if (vala_type_reference_get_is_ref (type2) != vala_type_reference_get_is_ref (self)) {
+		return FALSE;
+	}
 	if (vala_type_reference_get_is_out (type2) != vala_type_reference_get_is_out (self)) {
 		return FALSE;
 	}
@@ -427,15 +470,15 @@ gboolean vala_type_reference_stricter (ValaTypeReference* self, ValaTypeReferenc
 {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type2), FALSE);
-	if (vala_type_reference_get_reference_to_value_type (type2) != vala_type_reference_get_reference_to_value_type (self)) {
-		return FALSE;
-	}
 	if (vala_type_reference_get_transfers_ownership (type2) != vala_type_reference_get_transfers_ownership (self)) {
 		return FALSE;
 	}
 	if (vala_type_reference_get_takes_ownership (type2) != vala_type_reference_get_takes_ownership (self)) {
 		return FALSE;
 	}
+	if (vala_type_reference_get_is_ref (type2) != vala_type_reference_get_is_ref (self)) {
+		return FALSE;
+	}
 	if (vala_type_reference_get_is_out (type2) != vala_type_reference_get_is_out (self)) {
 		return FALSE;
 	}
@@ -457,20 +500,6 @@ gboolean vala_type_reference_stricter (ValaTypeReference* self, ValaTypeReferenc
 }
 
 
-gboolean vala_type_reference_get_reference_to_value_type (ValaTypeReference* self)
-{
-	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
-	return self->priv->_reference_to_value_type;
-}
-
-
-void vala_type_reference_set_reference_to_value_type (ValaTypeReference* self, gboolean value)
-{
-	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	self->priv->_reference_to_value_type = value;
-}
-
-
 gboolean vala_type_reference_get_transfers_ownership (ValaTypeReference* self)
 {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
@@ -564,10 +593,12 @@ ValaTypeParameter* vala_type_reference_get_type_parameter (ValaTypeReference* se
 
 void vala_type_reference_set_type_parameter (ValaTypeReference* self, ValaTypeParameter* value)
 {
+	ValaTypeParameter* __temp61;
+	ValaTypeParameter* __temp60;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	ValaTypeParameter* __temp62 = NULL;
-	ValaTypeParameter* __temp61 = NULL;
-	self->priv->_type_parameter = (__temp62 = (__temp61 = value, (__temp61 == NULL ? NULL : g_object_ref (__temp61))), (self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL))), __temp62);
+	__temp61 = NULL;
+	__temp60 = NULL;
+	self->priv->_type_parameter = (__temp61 = (__temp60 = value, (__temp60 == NULL ? NULL : g_object_ref (__temp60))), (self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL))), __temp61);
 }
 
 
@@ -594,10 +625,12 @@ char* vala_type_reference_get_namespace_name (ValaTypeReference* self)
 
 void vala_type_reference_set_namespace_name (ValaTypeReference* self, const char* value)
 {
+	char* __temp65;
+	const char* __temp64;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	char* __temp66 = NULL;
-	const char* __temp65 = NULL;
-	self->priv->_namespace_name = (__temp66 = (__temp65 = value, (__temp65 == NULL ? NULL : g_strdup (__temp65))), (self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL)), __temp66);
+	__temp65 = NULL;
+	__temp64 = NULL;
+	self->priv->_namespace_name = (__temp65 = (__temp64 = value, (__temp64 == NULL ? NULL : g_strdup (__temp64))), (self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL)), __temp65);
 }
 
 
@@ -610,10 +643,12 @@ char* vala_type_reference_get_type_name (ValaTypeReference* self)
 
 void vala_type_reference_set_type_name (ValaTypeReference* self, const char* value)
 {
+	char* __temp68;
+	const char* __temp67;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	char* __temp69 = NULL;
-	const char* __temp68 = NULL;
-	self->priv->_type_name = (__temp69 = (__temp68 = value, (__temp68 == NULL ? NULL : g_strdup (__temp68))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), __temp69);
+	__temp68 = NULL;
+	__temp67 = NULL;
+	self->priv->_type_name = (__temp68 = (__temp67 = value, (__temp67 == NULL ? NULL : g_strdup (__temp67))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), __temp68);
 }
 
 
@@ -675,11 +710,9 @@ void vala_type_reference_set_is_weak (ValaTypeReference* self, gboolean value)
 
 static void vala_type_reference_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaTypeReference * self = VALA_TYPE_REFERENCE (object);
+	ValaTypeReference * self;
+	self = VALA_TYPE_REFERENCE (object);
 	switch (property_id) {
-		case VALA_TYPE_REFERENCE_REFERENCE_TO_VALUE_TYPE:
-		g_value_set_boolean (value, vala_type_reference_get_reference_to_value_type (self));
-		break;
 		case VALA_TYPE_REFERENCE_TRANSFERS_OWNERSHIP:
 		g_value_set_boolean (value, vala_type_reference_get_transfers_ownership (self));
 		break;
@@ -728,11 +761,9 @@ static void vala_type_reference_get_property (GObject * object, guint property_i
 
 static void vala_type_reference_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaTypeReference * self = VALA_TYPE_REFERENCE (object);
+	ValaTypeReference * self;
+	self = VALA_TYPE_REFERENCE (object);
 	switch (property_id) {
-		case VALA_TYPE_REFERENCE_REFERENCE_TO_VALUE_TYPE:
-		vala_type_reference_set_reference_to_value_type (self, g_value_get_boolean (value));
-		break;
 		case VALA_TYPE_REFERENCE_TRANSFERS_OWNERSHIP:
 		vala_type_reference_set_transfers_ownership (self, g_value_get_boolean (value));
 		break;
@@ -787,7 +818,6 @@ static void vala_type_reference_class_init (ValaTypeReferenceClass * klass)
 	G_OBJECT_CLASS (klass)->set_property = vala_type_reference_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_type_reference_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_type_reference_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_REFERENCE_TO_VALUE_TYPE, g_param_spec_boolean ("reference-to-value-type", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_TRANSFERS_OWNERSHIP, g_param_spec_boolean ("transfers-ownership", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_TAKES_OWNERSHIP, g_param_spec_boolean ("takes-ownership", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_IS_OUT, g_param_spec_boolean ("is-out", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -813,13 +843,14 @@ static void vala_type_reference_init (ValaTypeReference * self)
 
 static void vala_type_reference_dispose (GObject * obj)
 {
-	ValaTypeReference * self = VALA_TYPE_REFERENCE (obj);
+	ValaTypeReference * self;
+	ValaTypeReferenceClass * klass;
+	GObjectClass * parent_class;
+	self = VALA_TYPE_REFERENCE (obj);
 	(self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL)));
 	(self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL));
 	(self->priv->_type_name = (g_free (self->priv->_type_name), NULL));
 	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_list_foreach (self->priv->type_argument_list, (GFunc) g_object_unref, NULL), g_list_free (self->priv->type_argument_list), NULL)));
-	ValaTypeReferenceClass * klass;
-	GObjectClass * parent_class;
 	klass = VALA_TYPE_REFERENCE_CLASS (g_type_class_peek (VALA_TYPE_TYPE_REFERENCE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
